VI_PROT_NORMAL = (1)
VI_PROT_HS488 = (3)
VI_PROT_FDC = (2)
VI_IO_OUT_BUF = (32)
VI_IO_OUT_BUF_DISCARD = (128)
VI_IO_IN_BUF = (16)
VI_IO_IN_BUF_DISCARD = (64)
VI_PROT_4882_STRS = (4)
VI_TRUE = (1)
VI_FALSE = (0)
NISCOPE_VAL_RESTORE_FACTORY_CALIBRATION = 2
IVI_ATTR_BASE = 1000000
IVI_ENGINE_PUBLIC_ATTR_BASE = (IVI_ATTR_BASE + 50000)
IVI_ATTR_QUERY_INSTRUMENT_STATUS = (IVI_ENGINE_PUBLIC_ATTR_BASE + 3)
NISCOPE_ATTR_QUERY_INSTRUMENT_STATUS = IVI_ATTR_QUERY_INSTRUMENT_STATUS
IVI_ATTR_SPECIFIC_DRIVER_REVISION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 551)
NISCOPE_ATTR_SPECIFIC_DRIVER_REVISION = IVI_ATTR_SPECIFIC_DRIVER_REVISION
IVI_VIREAL64_MAX = 1.79769313486231570814527423732e+308
IVI_VAL_NOT_USER_WRITABLE = (1 << 4)
IVI_VAL_NOT_USER_READABLE = (1 << 3)
VI_TMO_INFINITE = (0xFFFFFFFF)
IVI_VAL_MAX_TIME_INFINITE = VI_TMO_INFINITE
VI_TMO_IMMEDIATE = (0)
IVI_VAL_MAX_TIME_IMMEDIATE = VI_TMO_IMMEDIATE
VI_NULL = (0)
IVI_MAX_MESSAGE_LEN = 255
IVI_STATUS_CODE_BASE = 0x3FFA0000
_VI_ERROR = (-2147483647 - 1)
IVI_ERROR_BASE = (_VI_ERROR + IVI_STATUS_CODE_BASE)
IVI_NI_ERROR_BASE = (IVI_ERROR_BASE + 0x6000)
IVI_WARN_BASE = (IVI_STATUS_CODE_BASE)
IVI_ATTR_ATTRIBUTE_CAPABILITIES = (IVI_ENGINE_PUBLIC_ATTR_BASE + 403)
IVI_ATTR_BUFFERED_IO_CALLBACK = (IVI_ENGINE_PUBLIC_ATTR_BASE + 601)
IVI_ATTR_CACHE = (IVI_ENGINE_PUBLIC_ATTR_BASE + 4)
IVI_ATTR_CHANNEL_COUNT = (IVI_ENGINE_PUBLIC_ATTR_BASE + 203)
IVI_ATTR_CHECK_STATUS_CALLBACK = (IVI_ENGINE_PUBLIC_ATTR_BASE + 603)
IVI_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION = (
    IVI_ENGINE_PUBLIC_ATTR_BASE + 519)
IVI_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION = (
    IVI_ENGINE_PUBLIC_ATTR_BASE + 520)
IVI_ATTR_CLASS_DRIVER_DESCRIPTION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 518)
IVI_ATTR_CLASS_DRIVER_MAJOR_VERSION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 505)
IVI_ATTR_CLASS_DRIVER_MINOR_VERSION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 506)
IVI_ATTR_CLASS_DRIVER_PREFIX = (IVI_ENGINE_PUBLIC_ATTR_BASE + 301)
IVI_ATTR_CLASS_DRIVER_REVISION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 552)
IVI_ATTR_CLASS_DRIVER_VENDOR = (IVI_ENGINE_PUBLIC_ATTR_BASE + 517)
IVI_ATTR_CLASS_MAJOR_VERSION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 505)
IVI_ATTR_CLASS_MINOR_VERSION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 506)
IVI_ATTR_CLASS_PREFIX = (IVI_ENGINE_PUBLIC_ATTR_BASE + 301)
IVI_ATTR_CLASS_REVISION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 552)
IVI_ATTR_DEFER_UPDATE = (IVI_ENGINE_PUBLIC_ATTR_BASE + 51)
IVI_ATTR_DRIVER_MAJOR_VERSION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 503)
IVI_ATTR_DRIVER_MINOR_VERSION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 504)
IVI_ATTR_DRIVER_REVISION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 551)
IVI_ATTR_DRIVER_SETUP = (IVI_ENGINE_PUBLIC_ATTR_BASE + 7)
IVI_ATTR_ENGINE_MAJOR_VERSION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 501)
IVI_ATTR_ENGINE_MINOR_VERSION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 502)
IVI_ATTR_ENGINE_REVISION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 553)
IVI_ATTR_ERROR_ELABORATION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 103)
IVI_ATTR_FIRMWARE_REVISION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 510)
IVI_ATTR_FUNCTION_CAPABILITIES = (IVI_ENGINE_PUBLIC_ATTR_BASE + 402)
IVI_ATTR_GROUP_CAPABILITIES = (IVI_ENGINE_PUBLIC_ATTR_BASE + 401)
IVI_ATTR_INSTRUMENT_FIRMWARE_REVISION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 510)
IVI_ATTR_INSTRUMENT_MANUFACTURER = (IVI_ENGINE_PUBLIC_ATTR_BASE + 511)
IVI_ATTR_INSTRUMENT_MODEL = (IVI_ENGINE_PUBLIC_ATTR_BASE + 512)
IVI_ATTR_INTERCHANGE_CHECK = (IVI_ENGINE_PUBLIC_ATTR_BASE + 21)
IVI_ATTR_IO_RESOURCE_DESCRIPTOR = (IVI_ENGINE_PUBLIC_ATTR_BASE + 304)
IVI_ATTR_IO_SESSION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 322)
IVI_ATTR_IO_SESSION_TYPE = (IVI_ENGINE_PUBLIC_ATTR_BASE + 324)
IVI_ATTR_LOGICAL_NAME = (IVI_ENGINE_PUBLIC_ATTR_BASE + 305)
IVI_ATTR_MODULE_PATHNAME = (IVI_ENGINE_PUBLIC_ATTR_BASE + 303)
IVI_ATTR_NONE = 0xFFFFFFFF
IVI_ATTR_NUM_CHANNELS = (IVI_ENGINE_PUBLIC_ATTR_BASE + 203)
IVI_ATTR_OPC_CALLBACK = (IVI_ENGINE_PUBLIC_ATTR_BASE + 602)
IVI_ATTR_PRIMARY_ERROR = (IVI_ENGINE_PUBLIC_ATTR_BASE + 101)
IVI_ATTR_QUERY_INSTR_STATUS = IVI_ATTR_QUERY_INSTRUMENT_STATUS
IVI_ATTR_RANGE_CHECK = (IVI_ENGINE_PUBLIC_ATTR_BASE + 2)
IVI_ATTR_RECORD_COERCIONS = (IVI_ENGINE_PUBLIC_ATTR_BASE + 6)
IVI_ATTR_RESOURCE_DESCRIPTOR = IVI_ATTR_IO_RESOURCE_DESCRIPTOR
IVI_ATTR_RETURN_DEFERRED_VALUES = (IVI_ENGINE_PUBLIC_ATTR_BASE + 52)
IVI_ATTR_SECONDARY_ERROR = (IVI_ENGINE_PUBLIC_ATTR_BASE + 102)
IVI_ATTR_SIMULATE = (IVI_ENGINE_PUBLIC_ATTR_BASE + 5)
IVI_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION = (
    IVI_ENGINE_PUBLIC_ATTR_BASE + 515)
IVI_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION = (
    IVI_ENGINE_PUBLIC_ATTR_BASE + 516)
IVI_ATTR_SPECIFIC_DRIVER_DESCRIPTION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 514)
IVI_ATTR_SPECIFIC_DRIVER_LOCATOR = (IVI_ENGINE_PUBLIC_ATTR_BASE + 303)
IVI_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 503)
IVI_ATTR_SPECIFIC_DRIVER_MINOR_VERSION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 504)
IVI_ATTR_SPECIFIC_DRIVER_PREFIX = (IVI_ENGINE_PUBLIC_ATTR_BASE + 302)
IVI_ATTR_SPECIFIC_DRIVER_VENDOR = (IVI_ENGINE_PUBLIC_ATTR_BASE + 513)
IVI_ATTR_SPECIFIC_PREFIX = (IVI_ENGINE_PUBLIC_ATTR_BASE + 302)
IVI_ATTR_SPY = (IVI_ENGINE_PUBLIC_ATTR_BASE + 22)
IVI_ATTR_SUPPORTED_CLASSES = (IVI_ENGINE_PUBLIC_ATTR_BASE + 323)
IVI_ATTR_SUPPORTED_INSTRUMENT_MODELS = (IVI_ENGINE_PUBLIC_ATTR_BASE + 327)
IVI_ATTR_SUPPORTS_WR_BUF_OPER_MODE = (IVI_ENGINE_PUBLIC_ATTR_BASE + 704)
IVI_ATTR_UPDATING_VALUES = (IVI_ENGINE_PUBLIC_ATTR_BASE + 708)
IVI_ATTR_USER_INTERCHANGE_CHECK_CALLBACK = (IVI_ENGINE_PUBLIC_ATTR_BASE + 801)
IVI_ATTR_USE_SPECIFIC_SIMULATION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 23)
IVI_ATTR_VISA_RM_SESSION = (IVI_ENGINE_PUBLIC_ATTR_BASE + 321)
IVI_CLASS_ERROR_BASE = (IVI_ERROR_BASE + 0x2000)
IVI_CLASS_PRIVATE_ATTR_BASE = (IVI_ATTR_BASE + 200000)
IVI_CLASS_PUBLIC_ATTR_BASE = (IVI_ATTR_BASE + 250000)
IVI_CLASS_WARN_BASE = (IVI_WARN_BASE + 0x2000)
IVI_COMPILER_NAME = "Unknown"
IVI_COMPILER_VER_NUM = 1.0
IVI_CROSS_CLASS_ERROR_BASE = (IVI_ERROR_BASE + 0x1000)
IVI_CROSS_CLASS_WARN_BASE = (IVI_WARN_BASE + 0x1000)
IVI_ENGINE_MAJOR_VERSION = 2
IVI_ENGINE_MINOR_VERSION = 40
IVI_ENGINE_PRIVATE_ATTR_BASE = (IVI_ATTR_BASE + 00000)
IVI_ERROR_ACCESS_DENIED = (IVI_ERROR_BASE + 0x22)
IVI_ERROR_ADDR_ATTRS_MUST_BE_HIDDEN = (IVI_ERROR_BASE + 0x53)
IVI_ERROR_ALREADY_INITIALIZED = (IVI_ERROR_BASE + 0x61)
IVI_ERROR_ATTRIBUTE_NOT_SUPPORTED = (IVI_ERROR_BASE + 0x12)
IVI_ERROR_ATTRIBUTE_VALUE_NOT_KNOWN = (IVI_ERROR_BASE + 0x1A)
IVI_ERROR_ATTR_MUST_BE_CHANNEL_BASED = (IVI_ERROR_BASE + 0x47)
IVI_ERROR_ATTR_MUST_BE_REPEATED_CAPABILITY_BASED = IVI_ERROR_ATTR_MUST_BE_CHANNEL_BASED
IVI_ERROR_ATTR_NOT_CACHEABLE = (IVI_ERROR_BASE + 0x52)
IVI_ERROR_ATTR_NOT_VALID_FOR_CHANNEL = (IVI_ERROR_BASE + 0x46)
IVI_ERROR_ATTR_NOT_VALID_FOR_REPEATED_CAPABILITY = IVI_ERROR_ATTR_NOT_VALID_FOR_CHANNEL
IVI_ERROR_BAD_BOOLEAN_IN_CONFIG_FILE = (IVI_ERROR_BASE + 0x2C)
IVI_ERROR_BAD_CHANNEL_NAME = (IVI_ERROR_BASE + 0x54)
IVI_ERROR_BAD_DOUBLE_IN_CONFIG_FILE = (IVI_ERROR_BASE + 0x2B)
IVI_ERROR_BAD_INTEGER_IN_CONFIG_FILE = (IVI_ERROR_BASE + 0x2A)
IVI_ERROR_BADLY_FORMED_SELECTOR = (IVI_ERROR_BASE + 0x66)
IVI_ERROR_BAD_OPTION_NAME = (IVI_ERROR_BASE + 0x4B)
IVI_ERROR_BAD_OPTION_VALUE = (IVI_ERROR_BASE + 0x4C)
IVI_ERROR_BAD_PREFIX_IN_CONFIG_FILE = (IVI_ERROR_BASE + 0x55)
IVI_ERROR_BAD_REPEATED_CAPABILITY_NAME = IVI_ERROR_BAD_CHANNEL_NAME
IVI_ERROR_BAD_VIRT_CHAN_ASSIGNMENT = (IVI_ERROR_BASE + 0x43)
IVI_ERROR_BAD_VIRT_CHAN_NAME = (IVI_ERROR_BASE + 0x41)
IVI_ERROR_CANNOT_CHANGE_SIMULATION_STATE = (IVI_ERROR_BASE + 0x62)
IVI_ERROR_CANNOT_FIND_CVI_RTE = (IVI_ERROR_BASE + 0x30)
IVI_ERROR_CANNOT_LOAD_IVI_ENGINE = (IVI_ERROR_BASE + 0x00)
IVI_ERROR_CANNOT_MODIFY_REPEATED_CAPABILITY_TABLE = (IVI_NI_ERROR_BASE + 0)
IVI_ERROR_CANNOT_OPEN_CONFIG_FILE = (IVI_ERROR_BASE + 0x28)
IVI_ERROR_CANNOT_OPEN_CVI_RTE = (IVI_ERROR_BASE + 0x31)
IVI_ERROR_CANNOT_OPEN_DLL_FOR_EXPORTS = (IVI_ERROR_BASE + 0x37)
IVI_ERROR_CANNOT_OPEN_DRIVER_MODULE = (IVI_ERROR_BASE + 0x06)
IVI_ERROR_CANNOT_OPEN_FILE = (IVI_ERROR_BASE + 0x02)
IVI_ERROR_CANNOT_RECOVER = (IVI_ERROR_BASE + 0x00)
IVI_ERROR_CANNOT_RESTRICT_ATTRIBUTE_TWICE = (IVI_NI_ERROR_BASE + 1)
IVI_ERROR_CHANNEL_ALREADY_EXCLUDED = (IVI_ERROR_BASE + 0x48)
IVI_ERROR_CHANNEL_NAME_NOT_ALLOWED = (IVI_ERROR_BASE + 0x45)
IVI_ERROR_CHANNEL_NAME_REQUIRED = (IVI_ERROR_BASE + 0x44)
IVI_ERROR_CONFIG_ENTRY_NOT_FOUND = (IVI_ERROR_BASE + 0x2D)
IVI_ERROR_CONFIG_FILE_NOT_FOUND = (IVI_ERROR_BASE + 0x27)
IVI_ERROR_CONFIG_SERVER_NOT_PRESENT = (IVI_NI_ERROR_BASE + 0xD)
IVI_ERROR_CVI_RTE_INIT_FAILED = (IVI_ERROR_BASE + 0x34)
IVI_ERROR_CVI_RTE_INVALID_FORMAT = (IVI_ERROR_BASE + 0x32)
IVI_ERROR_CVI_RTE_MISSING_FUNCTION = (IVI_ERROR_BASE + 0x33)
IVI_ERROR_CVI_RTE_UNRESOLVED_SYMBOL = (IVI_ERROR_BASE + 0x35)
IVI_ERROR_DISK_FULL = (IVI_ERROR_BASE + 0x26)
IVI_ERROR_DLL_CORRUPTED = (IVI_ERROR_BASE + 0x38)
IVI_ERROR_DRIVER_DLL_INIT_FAILED = (IVI_ERROR_BASE + 0x2E)
IVI_ERROR_DRIVER_MODULE_NOT_FOUND = (IVI_ERROR_BASE + 0x05)
IVI_ERROR_DRIVER_UNRESOLVED_SYMBOL = (IVI_ERROR_BASE + 0x2F)
IVI_ERROR_DUPLICATE_CHANNEL_STRING = (IVI_ERROR_BASE + 0x3E)
IVI_ERROR_DUPLICATE_REPEATED_CAPABILITY_IDENTIFIER = IVI_ERROR_DUPLICATE_CHANNEL_STRING
IVI_ERROR_DUPLICATE_VIRT_CHAN_NAME = (IVI_ERROR_BASE + 0x3F)
IVI_ERROR_DUP_RUNTIME_CONFIG_ENTRY = (IVI_ERROR_BASE + 0x4F)
IVI_ERROR_EMPTY_CHANNEL_LIST = (IVI_ERROR_BASE + 0x3D)
IVI_ERROR_EMPTY_REPEATED_CAPABILITY_LIST = IVI_ERROR_EMPTY_CHANNEL_LIST
IVI_ERROR_ERROR_READING_CONFIG_FILE = (IVI_ERROR_BASE + 0x29)
IVI_ERROR_FILE_NOT_FOUND = (IVI_ERROR_BASE + 0x5B)
IVI_ERROR_FUNCTION_NOT_FOUND = (IVI_ERROR_BASE + 0x09)
IVI_ERROR_FUNCTION_NOT_SUPPORTED = (IVI_ERROR_BASE + 0x11)
IVI_ERROR_ID_QUERY_FAILED = (IVI_ERROR_BASE + 0x5E)
IVI_ERROR_INDEX_IS_ONE_BASED = (IVI_ERROR_BASE + 0x50)
IVI_ERROR_INDEX_IS_TOO_HIGH = (IVI_ERROR_BASE + 0x51)
IVI_ERROR_INSTR_SPECIFIC = (IVI_ERROR_BASE + 0x01)
IVI_ERROR_INSTRUMENT_STATUS = (IVI_ERROR_BASE + 0x01)
IVI_ERROR_INVALID_ATTRIBUTE = (IVI_ERROR_BASE + 0x0C)
IVI_ERROR_INVALID_CONFIGURATION = (IVI_ERROR_BASE + 0x18)
IVI_ERROR_INVALID_DEFAULT_SETUP_VAL = (IVI_ERROR_BASE + 0x3B)
IVI_ERROR_INVALID_DRIVER_MODULE = (IVI_ERROR_BASE + 0x07)
IVI_ERROR_INVALID_FILE_FORMAT = (IVI_ERROR_BASE + 0x5C)
IVI_ERROR_INVALID_NUMBER_OF_LEVELS_IN_SELECTOR = (IVI_ERROR_BASE + 0x63)
IVI_ERROR_INVALID_PARAMETER = (IVI_ERROR_BASE + 0x0F)
IVI_ERROR_INVALID_PATHNAME = (IVI_ERROR_BASE + 0x0B)
IVI_ERROR_INVALID_RANGE_IN_SELECTOR = (IVI_ERROR_BASE + 0x64)
IVI_ERROR_INVALID_RANGE_TABLE = (IVI_ERROR_BASE + 0x1C)
IVI_ERROR_INVALID_REPEATED_CAPABILITY_NAME = (IVI_NI_ERROR_BASE + 4)
IVI_ERROR_INVALID_TYPE = (IVI_ERROR_BASE + 0x14)
IVI_ERROR_INVALID_VALUE = (IVI_ERROR_BASE + 0x10)
IVI_ERROR_ITEM_ALREADY_EXISTS = (IVI_ERROR_BASE + 0x17)
IVI_ERROR_IVI_ATTR_NOT_READABLE = (IVI_ERROR_BASE + 0x0E)
IVI_ERROR_IVI_ATTR_NOT_WRITABLE = (IVI_ERROR_BASE + 0x0D)
IVI_ERROR_IVI_INI_IS_RESERVED = (IVI_ERROR_BASE + 0x4E)
IVI_ERROR_LOADING_CVI_RTE = (IVI_ERROR_BASE + 0x36)
IVI_ERROR_LOADING_DRIVER_MODULE = (IVI_ERROR_BASE + 0x0A)
IVI_ERROR_MISSING_OPTION_NAME = (IVI_ERROR_BASE + 0x49)
IVI_ERROR_MISSING_OPTION_VALUE = (IVI_ERROR_BASE + 0x4A)
IVI_ERROR_MISSING_VIRT_CHAN_NAME = (IVI_ERROR_BASE + 0x40)
IVI_ERROR_MULTIPLE_DEFERRED_SETTING = (IVI_ERROR_BASE + 0x16)
IVI_ERROR_NO_CHANNEL_TABLE = (IVI_ERROR_BASE + 0x1F)
IVI_ERROR_NO_DLL_EXPORT_TABLE = (IVI_ERROR_BASE + 0x39)
IVI_ERROR_NON_INTERCHANGEABLE_BEHAVIOR = (IVI_ERROR_BASE + 0x1E)
IVI_ERROR_NO_RANGE_TABLE = (IVI_ERROR_BASE + 0x1B)
IVI_ERROR_NOT_CREATED_BY_CLASS = (IVI_ERROR_BASE + 0x4D)
IVI_ERROR_NOT_INITIALIZED = (IVI_ERROR_BASE + 0x1D)
IVI_ERROR_NO_UNUSED_TEMP_FILENAMES = (IVI_ERROR_BASE + 0x25)
IVI_ERROR_NULL_POINTER = (IVI_ERROR_BASE + 0x58)
IVI_ERROR_OPERATION_PENDING = (IVI_ERROR_BASE + 0x57)
IVI_ERROR_OUT_OF_MEMORY = (IVI_ERROR_BASE + 0x56)
IVI_ERROR_READING_FILE = (IVI_ERROR_BASE + 0x03)
IVI_ERROR_REPEATED_CAPABILITY_ALREADY_EXISTS = (IVI_NI_ERROR_BASE + 2)
IVI_ERROR_REPEATED_CAPABILITY_NAME_NOT_ALLOWED = IVI_ERROR_CHANNEL_NAME_NOT_ALLOWED
IVI_ERROR_REPEATED_CAPABILITY_NAME_REQUIRED = IVI_ERROR_CHANNEL_NAME_REQUIRED
IVI_ERROR_REPEATED_CAPABILITY_NOT_DEFINED = (IVI_NI_ERROR_BASE + 3)
IVI_ERROR_RESET_FAILED = (IVI_ERROR_BASE + 0x5F)
IVI_ERROR_RESOURCE_UNKNOWN = (IVI_ERROR_BASE + 0x60)
IVI_ERROR_STATUS_NOT_AVAILABLE = (IVI_ERROR_BASE + 0x5D)
IVI_ERROR_SYS_RSRC_ALLOC = (IVI_ERROR_BASE + 0x21)
IVI_ERROR_TOO_MANY_FILES_OPEN = (IVI_ERROR_BASE + 0x23)
IVI_ERROR_TOO_MANY_OPEN_FILES = (IVI_ERROR_BASE + 0x23)
IVI_ERROR_TYPES_DO_NOT_MATCH = (IVI_ERROR_BASE + 0x15)
IVI_ERROR_UNABLE_TO_CREATE_TEMP_FILE = (IVI_ERROR_BASE + 0x24)
IVI_ERROR_UNASSIGNED_VIRT_CHAN_NAME = (IVI_ERROR_BASE + 0x42)
IVI_ERROR_UNDEFINED_REFERENCES = (IVI_ERROR_BASE + 0x08)
IVI_ERROR_UNEXPECTED_RESPONSE = (IVI_ERROR_BASE + 0x59)
IVI_ERROR_UNKNOWN_CHANNEL_NAME = (IVI_ERROR_BASE + 0x20)
IVI_ERROR_UNKNOWN_DEFAULT_SETUP_ATTR = (IVI_ERROR_BASE + 0x3A)
IVI_ERROR_UNKNOWN_MEMORY_PTR = (IVI_ERROR_BASE + 0x3C)
IVI_ERROR_UNKNOWN_PHYSICAL_IDENTIFIER = (IVI_ERROR_BASE + 0x67)
IVI_ERROR_UNKNOWN_REPEATED_CAPABILITY_NAME = IVI_ERROR_UNKNOWN_CHANNEL_NAME
IVI_ERROR_UNKOWN_NAME_IN_SELECTOR = (IVI_ERROR_BASE + 0x65)
IVI_ERROR_VALUE_NOT_AVAILABLE = (IVI_ERROR_BASE + 0x19)
IVI_ERROR_VALUE_NOT_SUPPORTED = (IVI_ERROR_BASE + 0x13)
IVI_ERROR_WRITING_FILE = (IVI_ERROR_BASE + 0x04)
IVI_MAX_DIRNAME_LEN = 256
IVI_MAX_DRIVENAME_LEN = 1
IVI_MAX_FILENAME_LEN = 256
IVI_MAX_MESSAGE_BUF_SIZE = (IVI_MAX_MESSAGE_LEN + 1)
IVI_MAX_PATHNAME_LEN = 1024
IVI_MAX_SPECIFIC_ERROR_CODE = (IVI_ERROR_BASE + 0x7FFF)
IVI_MAX_SPECIFIC_WARN_CODE = (IVI_WARN_BASE + 0x7FFF)
IVI_MSG_END_UPDATE = 2
IVI_MSG_FLUSH = 5
IVI_MSG_RESUME = 4
IVI_MSG_START_UPDATE = 1
IVI_MSG_SUSPEND = 3
IVI_NI_WARN_BASE = (IVI_WARN_BASE + 0x6000)
IVI_RANGE_TABLE_END_STRING = ((-1))
IVI_RANGE_TABLE_LAST_ENTRY = VI_NULL, VI_NULL, VI_NULL, IVI_RANGE_TABLE_END_STRING, VI_NULL
IVISCOPE_ATTR_AC_LINE_TRIGGER_SLOPE = (IVI_CLASS_PUBLIC_ATTR_BASE + 701)
IVISCOPE_ATTR_ACQUISITION_START_TIME = (IVI_CLASS_PUBLIC_ATTR_BASE + 109)
IVISCOPE_ATTR_ACQUISITION_TYPE = (IVI_CLASS_PUBLIC_ATTR_BASE + 101)
IVISCOPE_ATTR_ATTRIBUTE_CAPABILITIES = IVI_ATTR_ATTRIBUTE_CAPABILITIES
IVISCOPE_ATTR_BANDWIDTH = (IVI_CLASS_PUBLIC_ATTR_BASE + 6)
IVISCOPE_ATTR_CACHE = IVI_ATTR_CACHE
IVISCOPE_ATTR_CHANNEL_COUNT = IVI_ATTR_CHANNEL_COUNT
IVISCOPE_ATTR_CHANNEL_ENABLED = (IVI_CLASS_PUBLIC_ATTR_BASE + 5)
IVISCOPE_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION = IVI_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION
IVISCOPE_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION = IVI_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION
IVISCOPE_ATTR_CLASS_DRIVER_DESCRIPTION = IVI_ATTR_CLASS_DRIVER_DESCRIPTION
IVISCOPE_ATTR_CLASS_DRIVER_MAJOR_VERSION = IVI_ATTR_CLASS_DRIVER_MAJOR_VERSION
IVISCOPE_ATTR_CLASS_DRIVER_MINOR_VERSION = IVI_ATTR_CLASS_DRIVER_MINOR_VERSION
IVISCOPE_ATTR_CLASS_DRIVER_PREFIX = IVI_ATTR_CLASS_DRIVER_PREFIX
IVISCOPE_ATTR_CLASS_DRIVER_REVISION = IVI_ATTR_CLASS_DRIVER_REVISION
IVISCOPE_ATTR_CLASS_DRIVER_VENDOR = IVI_ATTR_CLASS_DRIVER_VENDOR
IVISCOPE_ATTR_CLASS_MAJOR_VERSION = IVI_ATTR_CLASS_MAJOR_VERSION
IVISCOPE_ATTR_CLASS_MINOR_VERSION = IVI_ATTR_CLASS_MINOR_VERSION
IVISCOPE_ATTR_CLASS_PREFIX = IVI_ATTR_CLASS_PREFIX
IVISCOPE_ATTR_CLASS_REVISION = IVI_ATTR_CLASS_REVISION
IVISCOPE_ATTR_DRIVER_MAJOR_VERSION = IVI_ATTR_DRIVER_MAJOR_VERSION
IVISCOPE_ATTR_DRIVER_MINOR_VERSION = IVI_ATTR_DRIVER_MINOR_VERSION
IVISCOPE_ATTR_DRIVER_REVISION = IVI_ATTR_DRIVER_REVISION
IVISCOPE_ATTR_DRIVER_SETUP = IVI_ATTR_DRIVER_SETUP
IVISCOPE_ATTR_ENGINE_MAJOR_VERSION = IVI_ATTR_ENGINE_MAJOR_VERSION
IVISCOPE_ATTR_ENGINE_MINOR_VERSION = IVI_ATTR_ENGINE_MINOR_VERSION
IVISCOPE_ATTR_ENGINE_REVISION = IVI_ATTR_ENGINE_REVISION
IVISCOPE_ATTR_ERROR_ELABORATION = IVI_ATTR_ERROR_ELABORATION
IVISCOPE_ATTR_FUNCTION_CAPABILITIES = IVI_ATTR_FUNCTION_CAPABILITIES
IVISCOPE_ATTR_GLITCH_CONDITION = (IVI_CLASS_PUBLIC_ATTR_BASE + 403)
IVISCOPE_ATTR_GLITCH_POLARITY = (IVI_CLASS_PUBLIC_ATTR_BASE + 402)
IVISCOPE_ATTR_GLITCH_WIDTH = (IVI_CLASS_PUBLIC_ATTR_BASE + 401)
IVISCOPE_ATTR_GROUP_CAPABILITIES = IVI_ATTR_GROUP_CAPABILITIES
IVISCOPE_ATTR_HORZ_MIN_NUM_PTS = (IVI_CLASS_PUBLIC_ATTR_BASE + 9)
IVISCOPE_ATTR_HORZ_RECORD_LENGTH = (IVI_CLASS_PUBLIC_ATTR_BASE + 8)
IVISCOPE_ATTR_HORZ_RECORD_REF_POSITION = (IVI_CLASS_PUBLIC_ATTR_BASE + 11)
IVISCOPE_ATTR_HORZ_SAMPLE_RATE = (IVI_CLASS_PUBLIC_ATTR_BASE + 10)
IVISCOPE_ATTR_HORZ_TIME_PER_RECORD = (IVI_CLASS_PUBLIC_ATTR_BASE + 7)
IVISCOPE_ATTR_INITIATE_CONTINUOUS = (IVI_CLASS_PUBLIC_ATTR_BASE + 107)
IVISCOPE_ATTR_INPUT_IMPEDANCE = (IVI_CLASS_PUBLIC_ATTR_BASE + 103)
IVISCOPE_ATTR_INSTRUMENT_FIRMWARE_REVISION = IVI_ATTR_INSTRUMENT_FIRMWARE_REVISION
IVISCOPE_ATTR_INSTRUMENT_MANUFACTURER = IVI_ATTR_INSTRUMENT_MANUFACTURER
IVISCOPE_ATTR_INSTRUMENT_MODEL = IVI_ATTR_INSTRUMENT_MODEL
IVISCOPE_ATTR_INTERCHANGE_CHECK = IVI_ATTR_INTERCHANGE_CHECK
IVISCOPE_ATTR_INTERPOLATION = (IVI_CLASS_PUBLIC_ATTR_BASE + 19)
IVISCOPE_ATTR_IO_RESOURCE_DESCRIPTOR = IVI_ATTR_IO_RESOURCE_DESCRIPTOR
IVISCOPE_ATTR_IO_SESSION = IVI_ATTR_IO_SESSION
IVISCOPE_ATTR_IO_SESSION_TYPE = IVI_ATTR_IO_SESSION_TYPE
IVISCOPE_ATTR_LOGICAL_NAME = IVI_ATTR_LOGICAL_NAME
IVISCOPE_ATTR_MAX_INPUT_FREQUENCY = (IVI_CLASS_PUBLIC_ATTR_BASE + 6)
IVISCOPE_ATTR_MEAS_HIGH_REF = (IVI_CLASS_PUBLIC_ATTR_BASE + 607)
IVISCOPE_ATTR_MEAS_LOW_REF = (IVI_CLASS_PUBLIC_ATTR_BASE + 608)
IVISCOPE_ATTR_MEAS_MID_REF = (IVI_CLASS_PUBLIC_ATTR_BASE + 609)
IVISCOPE_ATTR_MODULE_PATHNAME = IVI_ATTR_MODULE_PATHNAME
IVISCOPE_ATTR_NUM_AVERAGES = (IVI_CLASS_PUBLIC_ATTR_BASE + 104)
IVISCOPE_ATTR_NUM_CHANNELS = IVI_ATTR_NUM_CHANNELS
IVISCOPE_ATTR_NUM_ENVELOPES = (IVI_CLASS_PUBLIC_ATTR_BASE + 105)
IVISCOPE_ATTR_PRIMARY_ERROR = IVI_ATTR_PRIMARY_ERROR
IVISCOPE_ATTR_PROBE_ATTENUATION = (IVI_CLASS_PUBLIC_ATTR_BASE + 4)
IVISCOPE_ATTR_PROBE_SENSE_VALUE = (IVI_CLASS_PUBLIC_ATTR_BASE + 108)
IVISCOPE_ATTR_QUERY_INSTR_STATUS = IVI_ATTR_QUERY_INSTR_STATUS
IVISCOPE_ATTR_QUERY_INSTRUMENT_STATUS = IVI_ATTR_QUERY_INSTRUMENT_STATUS
IVISCOPE_ATTR_RANGE_CHECK = IVI_ATTR_RANGE_CHECK
IVISCOPE_ATTR_RECORD_COERCIONS = IVI_ATTR_RECORD_COERCIONS
IVISCOPE_ATTR_RESOURCE_DESCRIPTOR = IVI_ATTR_RESOURCE_DESCRIPTOR
IVISCOPE_ATTR_RUNT_HIGH_THRESHOLD = (IVI_CLASS_PUBLIC_ATTR_BASE + 301)
IVISCOPE_ATTR_RUNT_LOW_THRESHOLD = (IVI_CLASS_PUBLIC_ATTR_BASE + 302)
IVISCOPE_ATTR_RUNT_POLARITY = (IVI_CLASS_PUBLIC_ATTR_BASE + 303)
IVISCOPE_ATTR_SAMPLE_MODE = (IVI_CLASS_PUBLIC_ATTR_BASE + 106)
IVISCOPE_ATTR_SECONDARY_ERROR = IVI_ATTR_SECONDARY_ERROR
IVISCOPE_ATTR_SIMULATE = IVI_ATTR_SIMULATE
IVISCOPE_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION = IVI_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION
IVISCOPE_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION = IVI_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION
IVISCOPE_ATTR_SPECIFIC_DRIVER_DESCRIPTION = IVI_ATTR_SPECIFIC_DRIVER_DESCRIPTION
IVISCOPE_ATTR_SPECIFIC_DRIVER_LOCATOR = IVI_ATTR_SPECIFIC_DRIVER_LOCATOR
IVISCOPE_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION = IVI_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION
IVISCOPE_ATTR_SPECIFIC_DRIVER_MINOR_VERSION = IVI_ATTR_SPECIFIC_DRIVER_MINOR_VERSION
IVISCOPE_ATTR_SPECIFIC_DRIVER_PREFIX = IVI_ATTR_SPECIFIC_DRIVER_PREFIX
IVISCOPE_ATTR_SPECIFIC_DRIVER_REVISION = IVI_ATTR_SPECIFIC_DRIVER_REVISION
IVISCOPE_ATTR_SPECIFIC_DRIVER_VENDOR = IVI_ATTR_SPECIFIC_DRIVER_VENDOR
IVISCOPE_ATTR_SPECIFIC_PREFIX = IVI_ATTR_SPECIFIC_PREFIX
IVISCOPE_ATTR_SPY = IVI_ATTR_SPY
IVISCOPE_ATTR_SUPPORTED_INSTRUMENT_MODELS = IVI_ATTR_SUPPORTED_INSTRUMENT_MODELS
IVISCOPE_ATTR_TRIGGER_COUPLING = (IVI_CLASS_PUBLIC_ATTR_BASE + 14)
IVISCOPE_ATTR_TRIGGER_DELAY_TIME = (IVI_CLASS_PUBLIC_ATTR_BASE + 15)
IVISCOPE_ATTR_TRIGGER_HOLDOFF = (IVI_CLASS_PUBLIC_ATTR_BASE + 16)
IVISCOPE_ATTR_TRIGGER_LEVEL = (IVI_CLASS_PUBLIC_ATTR_BASE + 17)
IVISCOPE_ATTR_TRIGGER_MODIFIER = (IVI_CLASS_PUBLIC_ATTR_BASE + 102)
IVISCOPE_ATTR_TRIGGER_SLOPE = (IVI_CLASS_PUBLIC_ATTR_BASE + 18)
IVISCOPE_ATTR_TRIGGER_SOURCE = (IVI_CLASS_PUBLIC_ATTR_BASE + 13)
IVISCOPE_ATTR_TRIGGER_TYPE = (IVI_CLASS_PUBLIC_ATTR_BASE + 12)
IVISCOPE_ATTR_TV_TRIGGER_EVENT = (IVI_CLASS_PUBLIC_ATTR_BASE + 205)
IVISCOPE_ATTR_TV_TRIGGER_FIELD = (IVI_CLASS_PUBLIC_ATTR_BASE + 202)
IVISCOPE_ATTR_TV_TRIGGER_LINE = (IVI_CLASS_PUBLIC_ATTR_BASE + 203)
IVISCOPE_ATTR_TV_TRIGGER_LINE_NUMBER = (IVI_CLASS_PUBLIC_ATTR_BASE + 206)
IVISCOPE_ATTR_TV_TRIGGER_POLARITY = (IVI_CLASS_PUBLIC_ATTR_BASE + 204)
IVISCOPE_ATTR_TV_TRIGGER_SIGNAL_FORMAT = (IVI_CLASS_PUBLIC_ATTR_BASE + 201)
IVISCOPE_ATTR_TV_TRIGGER_SIGNAL_TYPE = (IVI_CLASS_PUBLIC_ATTR_BASE + 201)
IVISCOPE_ATTR_USE_SPECIFIC_SIMULATION = IVI_ATTR_USE_SPECIFIC_SIMULATION
IVISCOPE_ATTR_VERTICAL_COUPLING = (IVI_CLASS_PUBLIC_ATTR_BASE + 3)
IVISCOPE_ATTR_VERTICAL_OFFSET = (IVI_CLASS_PUBLIC_ATTR_BASE + 2)
IVISCOPE_ATTR_VERTICAL_RANGE = (IVI_CLASS_PUBLIC_ATTR_BASE + 1)
IVISCOPE_ATTR_WIDTH_CONDITION = (IVI_CLASS_PUBLIC_ATTR_BASE + 504)
IVISCOPE_ATTR_WIDTH_HIGH_THRESHOLD = (IVI_CLASS_PUBLIC_ATTR_BASE + 502)
IVISCOPE_ATTR_WIDTH_LOW_THRESHOLD = (IVI_CLASS_PUBLIC_ATTR_BASE + 501)
IVISCOPE_ATTR_WIDTH_POLARITY = (IVI_CLASS_PUBLIC_ATTR_BASE + 503)
IVISCOPE_DRIVER_DESCRIPTION = "IviScope Class Driver"
IVISCOPE_DRIVER_VENDOR = "National Instruments"
IVISCOPE_ERRMSG_CHANNEL_NOT_ENABLED = "Specified channel is not enabled."
IVISCOPE_ERRMSG_INVALID_ACQ_TYPE = "Invalid acquisition type."
IVISCOPE_ERRMSG_MAX_TIME_EXCEEDED = "Maximum time exceeded before the operation completed."
IVISCOPE_ERRMSG_UNABLE_TO_PERFORM_MEASUREMENT = "Unable to perform desired measurement operation."
IVISCOPE_ERROR_CHANNEL_NOT_ENABLED = (IVI_CLASS_ERROR_BASE + 0x0001)
IVISCOPE_ERROR_INVALID_ACQ_TYPE = (IVI_CLASS_ERROR_BASE + 0x0004)
IVISCOPE_ERROR_MAX_TIME_EXCEEDED = (IVI_CLASS_ERROR_BASE + 0x0003)
IVISCOPE_ERROR_UNABLE_TO_PERFORM_MEASUREMENT = (IVI_CLASS_ERROR_BASE + 0x0002)
IVISCOPE_MAJOR_VERSION = (3)
IVISCOPE_MINOR_VERSION = (0)
IVISCOPE_SPECIFICATION_MAJOR_VERSION = (3)
IVISCOPE_SPECIFICATION_MINOR_VERSION = (0)
IVISCOPE_VAL_1_MEG_OHM = (1000000.0)
IVISCOPE_VAL_50_OHMS = (50.0)
IVISCOPE_VAL_75_OHMS = (75.0)
IVISCOPE_VAL_AC = (0)
IVISCOPE_VAL_AC_LINE_EITHER = (3)
IVISCOPE_VAL_AC_LINE_NEGATIVE = (2)
IVISCOPE_VAL_AC_LINE_POSITIVE = (1)
IVISCOPE_VAL_AC_LINE_TRIGGER = (7)
IVISCOPE_VAL_AC_LINE = "VAL_AC_LINE"
IVISCOPE_VAL_ACQ_COMPLETE = (1)
IVISCOPE_VAL_ACQ_IN_PROGRESS = (0)
IVISCOPE_VAL_ACQ_STATUS_UNKNOWN = (-1)
IVISCOPE_VAL_ACQ_TYPE_CLASS_EXT_BASE = (100)
IVISCOPE_VAL_ACQ_TYPE_SPECIFIC_EXT_BASE = (1000)
IVISCOPE_VAL_ACQUISITION_TYPE_CLASS_EXT_BASE = (100)
IVISCOPE_VAL_ACQUISITION_TYPE_SPECIFIC_EXT_BASE = (1000)
IVISCOPE_VAL_AMPLITUDE = (15)
IVISCOPE_VAL_AUTO = (2)
IVISCOPE_VAL_AUTO_LEVEL = (3)
IVISCOPE_VAL_AVERAGE = (4)
IVISCOPE_VAL_CALCULATION_SPECIFIC_DRIVER_BASE = (1000)
IVISCOPE_VAL_DC = (1)
IVISCOPE_VAL_DUTY_CYCLE_NEG = (13)
IVISCOPE_VAL_DUTY_CYCLE_POS = (14)
IVISCOPE_VAL_ECL0 = "VAL_ECL0"
IVISCOPE_VAL_ECL1 = "VAL_ECL1"
IVISCOPE_VAL_EDGE = (1)
IVISCOPE_VAL_EDGE_TRIGGER = (1)
IVISCOPE_VAL_ENVELOPE = (3)
IVISCOPE_VAL_EQUIVALENT_TIME = (1)
IVISCOPE_VAL_EXTERNAL = "VAL_EXTERNAL"
IVISCOPE_VAL_FALL_TIME = (1)
IVISCOPE_VAL_FREQUENCY = (2)
IVISCOPE_VAL_GLITCH = (103)
IVISCOPE_VAL_GLITCH_EITHER = (3)
IVISCOPE_VAL_GLITCH_GREATER_THAN = (2)
IVISCOPE_VAL_GLITCH_LESS_THAN = (1)
IVISCOPE_VAL_GLITCH_NEGATIVE = (2)
IVISCOPE_VAL_GLITCH_POSITIVE = (1)
IVISCOPE_VAL_GLITCH_TRIGGER = (4)
IVISCOPE_VAL_GND = (2)
IVISCOPE_VAL_GPIB_GET = "VAL_GPIB_GET"
IVISCOPE_VAL_HF_REJECT = (3)
IVISCOPE_VAL_HI_RES = (2)
IVISCOPE_VAL_IMMEDIATE_TRIGGER = (6)
IVISCOPE_VAL_IMMEDIATE = "VAL_IMMEDIATE"
IVISCOPE_VAL_INFINITE = (-1)
IVISCOPE_VAL_INTERPOLATION_CLASS_EXT_BASE = (100)
IVISCOPE_VAL_INTERPOLATION_SPECIFIC_EXT_BASE = (1000)
IVISCOPE_VAL_INVALID_WFM_VOLTAGE = (1.0E+301)
IVISCOPE_VAL_LF_REJECT = (4)
IVISCOPE_VAL_LINEAR = (3)
IVISCOPE_VAL_MAX_TIME_IMMEDIATE = IVI_VAL_MAX_TIME_IMMEDIATE
IVISCOPE_VAL_MAX_TIME_INFINITE = IVI_VAL_MAX_TIME_INFINITE
IVISCOPE_VAL_MAX_VALID_WFM_VOLTAGE = (1.0E+300)
IVISCOPE_VAL_MEASUREMENT_FUNCTION_CLASS_EXT_BASE = (100)
IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE = (1000)
IVISCOPE_VAL_NEGATIVE = (0)
IVISCOPE_VAL_NO_INTERPOLATION = (1)
IVISCOPE_VAL_NOISE_REJECT = (5)
IVISCOPE_VAL_NORMAL = (0)
IVISCOPE_VAL_NO_TRIGGER_MOD = (1)
IVISCOPE_VAL_NTSC = (1)
IVISCOPE_VAL_OVERSHOOT = (18)
IVISCOPE_VAL_PAL = (2)
IVISCOPE_VAL_PATTERN = (105)
IVISCOPE_VAL_PEAK_DETECT = (1)
IVISCOPE_VAL_PERIOD = (3)
IVISCOPE_VAL_POSITIVE = (1)
IVISCOPE_VAL_PRESHOOT = (19)
IVISCOPE_VAL_PROBE_ATTENUATION_CLASS_EXT_BASE = (-100)
IVISCOPE_VAL_PROBE_ATTENUATION_SPECIFIC_EXT_BASE = (-1000)
IVISCOPE_VAL_PROBE_SENSE_ON = (-1)
IVISCOPE_VAL_PXI_STAR = "VAL_PXI_STAR"
IVISCOPE_VAL_REAL_TIME = (0)
IVISCOPE_VAL_RISE_TIME = (0)
IVISCOPE_VAL_RTSI_0 = "VAL_RTSI_0"
IVISCOPE_VAL_RTSI_1 = "VAL_RTSI_1"
IVISCOPE_VAL_RTSI_2 = "VAL_RTSI_2"
IVISCOPE_VAL_RTSI_3 = "VAL_RTSI_3"
IVISCOPE_VAL_RTSI_4 = "VAL_RTSI_4"
IVISCOPE_VAL_RTSI_5 = "VAL_RTSI_5"
IVISCOPE_VAL_RTSI_6 = "VAL_RTSI_6"
IVISCOPE_VAL_RUNT = (102)
IVISCOPE_VAL_RUNT_EITHER = (3)
IVISCOPE_VAL_RUNT_NEGATIVE = (2)
IVISCOPE_VAL_RUNT_POSITIVE = (1)
IVISCOPE_VAL_RUNT_TRIGGER = (3)
IVISCOPE_VAL_SECAM = (3)
IVISCOPE_VAL_SINE_X = (2)
IVISCOPE_VAL_STATE = (104)
IVISCOPE_VAL_SW_TRIG_FUNC = "VAL_SW_TRIG_FUNC"
IVISCOPE_VAL_TRIGGER_COUPLING_CLASS_EXT_BASE = (100)
IVISCOPE_VAL_TRIGGER_COUPLING_SPECIFIC_EXT_BASE = (1000)
IVISCOPE_VAL_TRIGGER_MOD_CLASS_EXT_BASE = (100)
IVISCOPE_VAL_TRIGGER_MOD_SPECIFIC_EXT_BASE = (1000)
IVISCOPE_VAL_TRIGGER_TYPE_CLASS_EXT_BASE = (200)
IVISCOPE_VAL_TRIGGER_TYPE_SPECIFIC_EXT_BASE = (1000)
IVISCOPE_VAL_TTL0 = "VAL_TTL0"
IVISCOPE_VAL_TTL1 = "VAL_TTL1"
IVISCOPE_VAL_TTL2 = "VAL_TTL2"
IVISCOPE_VAL_TTL3 = "VAL_TTL3"
IVISCOPE_VAL_TTL4 = "VAL_TTL4"
IVISCOPE_VAL_TTL5 = "VAL_TTL5"
IVISCOPE_VAL_TTL6 = "VAL_TTL6"
IVISCOPE_VAL_TTL7 = "VAL_TTL7"
IVISCOPE_VAL_TV = (106)
IVISCOPE_VAL_TV_ANY_FIELD = (-1)
IVISCOPE_VAL_TV_EVENT_ANY_FIELD = (3)
IVISCOPE_VAL_TV_EVENT_ANY_LINE = (4)
IVISCOPE_VAL_TV_EVENT_FIELD1 = (1)
IVISCOPE_VAL_TV_EVENT_FIELD2 = (2)
IVISCOPE_VAL_TV_EVENT_LINE_NUMBER = (5)
IVISCOPE_VAL_TV_FIELD1 = (1)
IVISCOPE_VAL_TV_FIELD2 = (2)
IVISCOPE_VAL_TV_NEGATIVE = (2)
IVISCOPE_VAL_TV_POSITIVE = (1)
IVISCOPE_VAL_TV_SIGNAL_FORMAT_CLASS_EXT_BASE = (100)
IVISCOPE_VAL_TV_SIGNAL_FORMAT_SPECIFIC_EXT_BASE = (1000)
IVISCOPE_VAL_TV_SIGNAL_TYPE_CLASS_EXT_BASE = (100)
IVISCOPE_VAL_TV_SIGNAL_TYPE_SPECIFIC_EXT_BASE = (1000)
IVISCOPE_VAL_TV_TRIGGER = (5)
IVISCOPE_VAL_TV_TRIGGER_EVENT_CLASS_EXT_BASE = (100)
IVISCOPE_VAL_TV_TRIGGER_EVENT_SPECIFIC_EXT_BASE = (1000)
IVISCOPE_VAL_TV_TRIGGER_FIELD_CLASS_EXT_BASE = (100)
IVISCOPE_VAL_TV_TRIGGER_FIELD_SPECIFIC_EXT_BASE = (1000)
IVISCOPE_VAL_TV_TRIGGER_POLARITY_CLASS_EXT_BASE = (100)
IVISCOPE_VAL_TV_TRIGGER_POLARITY_SPECIFIC_EXT_BASE = (1000)
IVISCOPE_VAL_VERTICAL_COUPLING_CLASS_EXT_BASE = (100)
IVISCOPE_VAL_VERTICAL_COUPLING_SPECIFIC_EXT_BASE = (1000)
IVISCOPE_VAL_VOLTAGE_AVERAGE = (10)
IVISCOPE_VAL_VOLTAGE_CYCLE_AVERAGE = (17)
IVISCOPE_VAL_VOLTAGE_CYCLE_RMS = (16)
IVISCOPE_VAL_VOLTAGE_HIGH = (8)
IVISCOPE_VAL_VOLTAGE_LOW = (9)
IVISCOPE_VAL_VOLTAGE_MAX = (6)
IVISCOPE_VAL_VOLTAGE_MIN = (7)
IVISCOPE_VAL_VOLTAGE_PEAK_TO_PEAK = (5)
IVISCOPE_VAL_VOLTAGE_RMS = (4)
IVISCOPE_VAL_WIDTH = (101)
IVISCOPE_VAL_WIDTH_EITHER = (3)
IVISCOPE_VAL_WIDTH_NEG = (11)
IVISCOPE_VAL_WIDTH_NEGATIVE = (2)
IVISCOPE_VAL_WIDTH_OUTSIDE = (2)
IVISCOPE_VAL_WIDTH_POS = (12)
IVISCOPE_VAL_WIDTH_POSITIVE = (1)
IVISCOPE_VAL_WIDTH_TRIGGER = (2)
IVISCOPE_VAL_WIDTH_WITHIN = (1)
IVISCOPE_WARN_INVALID_WFM_ELEMENT = (IVI_CLASS_WARN_BASE + 0x0001)
IVISCOPE_WARNMSG_INVALID_WFM_ELEMENT = "One of the elements in the waveform array is invalid."
IVI_SHARED_COMPONENT_ERROR_BASE = (IVI_ERROR_BASE + 0x1000)
IVI_SPECIFIC_ERROR_BASE = (IVI_ERROR_BASE + 0x4000)
IVI_SPECIFIC_PRIVATE_ATTR_BASE = (IVI_ATTR_BASE + 100000)
IVI_SPECIFIC_PUBLIC_ATTR_BASE = (IVI_ATTR_BASE + 150000)
IVI_SPECIFIC_WARN_BASE = (IVI_WARN_BASE + 0x4000)
IVI_VAL_400_HERTZ = 400.0
IVI_VAL_50_HERTZ = 50.0
IVI_VAL_60_HERTZ = 60.0
IVI_VAL_ADDR = 10
IVI_VAL_ALL_CHANNELS = "IVI_ALL_CHANNELS"
IVI_VAL_ALL_INSTANCES = IVI_VAL_ALL_CHANNELS
IVI_VAL_ALWAYS_CACHE = (1 << 6)
IVI_VAL_APPEND = 2
IVI_VAL_ATTR_SET_TO_INSTR_SPECIFIC_VALUE = 3
IVI_VAL_BOOLEAN = 13
IVI_VAL_CHECK_CALLBACK = 4
IVI_VAL_CHECK_CALL_CLASS_CALLBACK = 3
IVI_VAL_CHECK_EXEMPT = 4
IVI_VAL_CHECK_IN_USER_SPECIFIED_STATE = 1
IVI_VAL_CHECK_READ_ONLY_ATTR_NEVER_SET = 2
IVI_VAL_CLASS_DEFINED_INTERCHANGE_WARNING = 5
IVI_VAL_COERCEABLE_ONLY_BY_INSTR = (1 << 11)
IVI_VAL_COERCE_CALLBACK = 5
IVI_VAL_COERCED = 2
IVI_VAL_COMPARE_CALLBACK = 3
IVI_VAL_DIRECT_USER_CALL = (1 << 0)
IVI_VAL_DISCRETE = 0
IVI_VAL_DONT_CHECK_STATUS = (1 << 15)
IVI_VAL_DONT_MARK_AS_SET_BY_USER = (1 << 2)
IVI_VAL_DONT_RETURN_DEFERRED_VALUE = (1 << 8)
IVI_VAL_FAILURE_APPLYING_UNUSED_EXTENSION_VALUE = 4
IVI_VAL_FLUSH_ON_WRITE = (1 << 9)
IVI_VAL_HIDDEN = (IVI_VAL_NOT_USER_READABLE | IVI_VAL_NOT_USER_WRITABLE)
IVI_VAL_INT32 = 1
IVI_VAL_MULTI_CHANNEL = (1 << 10)
IVI_VAL_NEVER_CACHE = (1 << 5)
IVI_VAL_NI4882_SESSION_TYPE = "NI-488.2"
IVI_VAL_NIDAQ_SESSION_TYPE = "NI-DAQ"
IVI_VAL_NISERIAL_SESSION_TYPE = "NI-Serial"
IVI_VAL_NIVXI_SESSION_TYPE = "NI-VXI"
IVI_VAL_NO_DEFERRED_UPDATE = (1 << 7)
IVI_VAL_NOT_IN_USER_SPECIFIED_STATE = 1
IVI_VAL_NOT_READABLE = (1 << 1)
IVI_VAL_NOT_SUPPORTED = (1 << 0)
IVI_VAL_NOT_WRITABLE = (1 << 2)
IVI_VAL_NO_WAIT = 0
IVI_VAL_RANGED = 1
IVI_VAL_RANGE_TABLE_CALLBACK = 6
IVI_VAL_READ_CALLBACK = 1
IVI_VAL_READ_ONLY_ATTR_SET_BY_USER = 2
IVI_VAL_REAL64 = 4
IVI_VAL_SESSION = 11
IVI_VAL_SET_CACHE_ONLY = (1 << 1)
IVI_VAL_STRING = 5
IVI_VAL_TRUNCATE = 1
IVI_VAL_TYPE_NAN = 1
IVI_VAL_TYPE_NINF = 3
IVI_VAL_TYPE_NORMAL = 0
IVI_VAL_TYPE_PINF = 2
IVI_VAL_UNKNOWN_TYPE = 14
IVI_VAL_USE_CALLBACKS_FOR_SIMULATION = (1 << 14)
IVI_VAL_VISA_SESSION_TYPE = "VISA"
IVI_VAL_WAIT_FOREVER = IVI_VIREAL64_MAX
IVI_VAL_WAIT_FOR_OPC_AFTER_WRITES = (1 << 13)
IVI_VAL_WAIT_FOR_OPC_BEFORE_READS = (1 << 12)
IVI_VAL_WRITE_CALLBACK = 2
IVI_VIREAL64_MAX_NEG = (-IVI_VIREAL64_MAX)
IVI_WARN_NSUP_ERROR_QUERY = (IVI_WARN_BASE + 0x68)
IVI_WARN_NSUP_ID_QUERY = (IVI_WARN_BASE + 0x65)
IVI_WARN_NSUP_RESET = (IVI_WARN_BASE + 0x66)
IVI_WARN_NSUP_REV_QUERY = (IVI_WARN_BASE + 0x69)
IVI_WARN_NSUP_SELF_TEST = (IVI_WARN_BASE + 0x67)
NISCOPE_ATTR_5102_ADJUST_PRETRIGGER_SAMPLES = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 85)
NISCOPE_ATTR_ACQ_ARM_SOURCE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 53)
NISCOPE_ATTR_ACQUISITION_START_TIME = IVISCOPE_ATTR_ACQUISITION_START_TIME
NISCOPE_ATTR_ACQUISITION_TYPE = IVISCOPE_ATTR_ACQUISITION_TYPE
NISCOPE_ATTR_ADV_TRIG_SRC = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 94)
NISCOPE_ATTR_ALLOW_MORE_RECORDS_THAN_MEMORY = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 68)
NISCOPE_ATTR_ARM_REF_TRIG_SRC = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 95)
NISCOPE_ATTR_BACKLOG = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 84)
NISCOPE_ATTR_BANDWIDTH = IVISCOPE_ATTR_BANDWIDTH
NISCOPE_ATTR_BINARY_SAMPLE_WIDTH = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 5)
NISCOPE_ATTR_CACHE = IVI_ATTR_CACHE
NISCOPE_ATTR_CHANNEL_COUNT = IVI_ATTR_CHANNEL_COUNT
NISCOPE_ATTR_CHANNEL_ENABLED = IVISCOPE_ATTR_CHANNEL_ENABLED
NISCOPE_ATTR_CHANNEL_TERMINAL_CONFIGURATION = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 107)
NISCOPE_ATTR_CLOCK_SYNC_PULSE_SOURCE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 7)
NISCOPE_ATTR_DAQMX_TASK = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 92)
NISCOPE_ATTR_DDC_AGC_AVERAGE_CONTROL = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1047)
NISCOPE_ATTR_DDC_AGC_LOOP_GAIN_0_EXPONENT = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1042)
NISCOPE_ATTR_DDC_AGC_LOOP_GAIN_0_MANTISSA = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1043)
NISCOPE_ATTR_DDC_AGC_LOOP_GAIN_1_EXPONENT = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1044)
NISCOPE_ATTR_DDC_AGC_LOOP_GAIN_1_MANTISSA = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1045)
NISCOPE_ATTR_DDC_AGC_LOWER_GAIN_LIMIT = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1041)
NISCOPE_ATTR_DDC_AGC_THRESHOLD = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1046)
NISCOPE_ATTR_DDC_AGC_UPPER_GAIN_LIMIT = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1040)
NISCOPE_ATTR_DDC_AOUT_PARALLEL_OUTPUT_SOURCE = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1070)
NISCOPE_ATTR_DDC_BOUT_PARALLEL_OUTPUT_SOURCE = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1071)
NISCOPE_ATTR_DDC_CIC_DECIMATION = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1010)
NISCOPE_ATTR_DDC_CIC_SHIFT_GAIN = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1011)
NISCOPE_ATTR_DDC_COMBINED_DECIMATION = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1301)
NISCOPE_ATTR_DDC_COORDINATE_CONVERTER_INPUT = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1073)
NISCOPE_ATTR_DDC_DIRECT_REGISTER_ADDRESS = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1305)
NISCOPE_ATTR_DDC_DIRECT_REGISTER_DATA = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1306)
NISCOPE_ATTR_DDC_DISCRIMINATOR_DELAY = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1025)
NISCOPE_ATTR_DDC_DISCRIMINATOR_ENABLED = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1020)
NISCOPE_ATTR_DDC_DISCRIMINATOR_FIR_DECIMATION = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1021)
NISCOPE_ATTR_DDC_DISCRIMINATOR_FIR_INPUT_SOURCE = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1026)
NISCOPE_ATTR_DDC_DISCRIMINATOR_FIR_NUM_TAPS = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1024)
NISCOPE_ATTR_DDC_DISCRIMINATOR_FIR_SYMMETRY = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1022)
NISCOPE_ATTR_DDC_DISCRIMINATOR_FIR_SYMMETRY_TYPE = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1023)
NISCOPE_ATTR_DDC_DISCRIMINATOR_PHASE_MULTIPLIER = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1027)
NISCOPE_ATTR_DDC_ENABLE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1003)
NISCOPE_ATTR_DDC_HALFBAND_1_ENABLED = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1051)
NISCOPE_ATTR_DDC_HALFBAND_2_ENABLED = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1052)
NISCOPE_ATTR_DDC_HALFBAND_3_ENABLED = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1053)
NISCOPE_ATTR_DDC_HALFBAND_4_ENABLED = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1054)
NISCOPE_ATTR_DDC_HALFBAND_5_ENABLED = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1055)
NISCOPE_ATTR_DDC_HALFBAND_BYPASSED = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1050)
NISCOPE_ATTR_DDC_NCO_DIVIDE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1129)
NISCOPE_ATTR_DDC_NCO_FREQUENCY = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1000)
NISCOPE_ATTR_DDC_NCO_PHASE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1001)
NISCOPE_ATTR_DDC_PFIR_DECIMATION = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1030)
NISCOPE_ATTR_DDC_PFIR_NUM_TAPS = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1033)
NISCOPE_ATTR_DDC_PFIR_REAL_OR_COMPLEX = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1034)
NISCOPE_ATTR_DDC_PFIR_SYMMETRY = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1031)
NISCOPE_ATTR_DDC_PFIR_SYMMETRY_TYPE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1032)
NISCOPE_ATTR_DDC_Q_INPUT_TO_COORD_CONVERTER_INPUT = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1074)
NISCOPE_ATTR_DDC_REFERENCE_DIVIDE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1130)
NISCOPE_ATTR_DDC_RESAMPLER_BYPASS = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1127)
NISCOPE_ATTR_DDC_RESAMPLER_FILTER_MODE_SELECT = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1126)
NISCOPE_ATTR_DDC_RESAMPLER_OUTPUT_PULSE_DELAY = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1128)
NISCOPE_ATTR_DDC_SYNCOUT_CLK_SELECT = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1080)
NISCOPE_ATTR_DDC_TEST_SINE_COSINE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1072)
NISCOPE_ATTR_DDC_TIMING_NCO_CENTER_FREQUENCY = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1124)
NISCOPE_ATTR_DDC_TIMING_NCO_CLEAR_PHASE_ACCUM = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1121)
NISCOPE_ATTR_DDC_TIMING_NCO_ENABLE_OFFSET_FREQ = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1122)
NISCOPE_ATTR_DDC_TIMING_NCO_NUM_OFFSET_FREQ_BITS = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1123)
NISCOPE_ATTR_DDC_TIMING_NCO_PHASE_ACCUM_LOAD = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1120)
NISCOPE_ATTR_DDC_TIMING_NCO_PHASE_OFFSET = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1125)
NISCOPE_ATTR_DEFER_UPDATE = IVI_ATTR_DEFER_UPDATE
NISCOPE_ATTR_DELAY_BEFORE_INITIATE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1304)
NISCOPE_ATTR_DEVICE_NUMBER = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 76)
NISCOPE_ATTR_DEVICE_TEMPERATURE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 86)
NISCOPE_ATTR_DRIVER_MAJOR_VERSION = IVI_ATTR_DRIVER_MAJOR_VERSION
NISCOPE_ATTR_DRIVER_MINOR_VERSION = IVI_ATTR_DRIVER_MINOR_VERSION
NISCOPE_ATTR_DRIVER_REVISION = NISCOPE_ATTR_SPECIFIC_DRIVER_REVISION
NISCOPE_ATTR_DRIVER_SETUP = IVI_ATTR_DRIVER_SETUP
NISCOPE_ATTR_ENABLE_DC_RESTORE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 93)
NISCOPE_ATTR_ENABLE_DITHER = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1300)
NISCOPE_ATTR_ENGINE_MAJOR_VERSION = IVI_ATTR_ENGINE_MAJOR_VERSION
NISCOPE_ATTR_ENGINE_MINOR_VERSION = IVI_ATTR_ENGINE_MINOR_VERSION
NISCOPE_ATTR_ENGINE_REVISION = IVI_ATTR_ENGINE_REVISION
NISCOPE_ATTR_ERROR_ELABORATION = IVI_ATTR_ERROR_ELABORATION
NISCOPE_ATTR_EXPORTED_ADVANCE_TRIGGER_OUTPUT_TERMINAL = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 109)
NISCOPE_ATTR_EXPORTED_SAMPLE_CLOCK_OUTPUT_TERMINAL = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 91)
NISCOPE_ATTR_EXPORT_SAMP_CLK_OUTPUT_TERM = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 91)
NISCOPE_ATTR_FETCH_INTERLEAVED_DATA = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 72)
NISCOPE_ATTR_FETCH_MEAS_NUM_SAMPLES = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 81)
NISCOPE_ATTR_FETCH_NUM_RECORDS = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 80)
NISCOPE_ATTR_FETCH_OFFSET = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 78)
NISCOPE_ATTR_FETCH_RECORD_NUMBER = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 79)
NISCOPE_ATTR_FETCH_RELATIVE_TO = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 77)
NISCOPE_ATTR_FLEX_FIR_ANTIALIAS_FILTER_TYPE = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 271)
NISCOPE_ATTR_GROUP_CAPABILITIES = IVI_ATTR_GROUP_CAPABILITIES
NISCOPE_ATTR_HORZ_ENFORCE_REALTIME = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 4)
NISCOPE_ATTR_HORZ_MIN_NUM_PTS = IVISCOPE_ATTR_HORZ_MIN_NUM_PTS
NISCOPE_ATTR_HORZ_NUM_RECORDS = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1)
NISCOPE_ATTR_HORZ_RECORD_LENGTH = IVISCOPE_ATTR_HORZ_RECORD_LENGTH
NISCOPE_ATTR_HORZ_RECORD_REF_POSITION = IVISCOPE_ATTR_HORZ_RECORD_REF_POSITION
NISCOPE_ATTR_HORZ_SAMPLE_RATE = IVISCOPE_ATTR_HORZ_SAMPLE_RATE
NISCOPE_ATTR_HORZ_TIME_PER_RECORD = IVISCOPE_ATTR_HORZ_TIME_PER_RECORD
NISCOPE_ATTR_INPUT_CLOCK_SOURCE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 2)
NISCOPE_ATTR_INPUT_IMPEDANCE = IVISCOPE_ATTR_INPUT_IMPEDANCE
NISCOPE_ATTR_INSTRUMENT_FIRMWARE_REVISION = IVI_ATTR_INSTRUMENT_FIRMWARE_REVISION
NISCOPE_ATTR_INSTRUMENT_MANUFACTURER = IVI_ATTR_INSTRUMENT_MANUFACTURER
NISCOPE_ATTR_INSTRUMENT_MODEL = IVI_ATTR_INSTRUMENT_MODEL
NISCOPE_ATTR_INTERCHANGE_CHECK = IVI_ATTR_INTERCHANGE_CHECK
NISCOPE_ATTR_IO_RESOURCE_DESCRIPTOR = IVI_ATTR_IO_RESOURCE_DESCRIPTOR
NISCOPE_ATTR_IO_SESSION = IVI_ATTR_IO_SESSION
NISCOPE_ATTR_IS_PROBE_COMP_ON = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 66)
NISCOPE_ATTR_LOGICAL_NAME = IVI_ATTR_LOGICAL_NAME
NISCOPE_ATTR_MASTER_ENABLE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 8)
NISCOPE_ATTR_MAX_INPUT_FREQUENCY = IVISCOPE_ATTR_MAX_INPUT_FREQUENCY
NISCOPE_ATTR_MAX_REAL_TIME_SAMPLING_RATE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 73)
NISCOPE_ATTR_MAX_RIS_RATE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 74)
NISCOPE_ATTR_MEAS_ARRAY_GAIN = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 43)
NISCOPE_ATTR_MEAS_ARRAY_OFFSET = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 44)
NISCOPE_ATTR_MEAS_CHAN_HIGH_REF_LEVEL = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 40)
NISCOPE_ATTR_MEAS_CHAN_LOW_REF_LEVEL = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 38)
NISCOPE_ATTR_MEAS_CHAN_MID_REF_LEVEL = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 39)
NISCOPE_ATTR_MEAS_FILTER_CENTER_FREQ = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 32)
NISCOPE_ATTR_MEAS_FILTER_CUTOFF_FREQ = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 31)
NISCOPE_ATTR_MEAS_FILTER_ORDER = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 36)
NISCOPE_ATTR_MEAS_FILTER_RIPPLE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 33)
NISCOPE_ATTR_MEAS_FILTER_TAPS = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 37)
NISCOPE_ATTR_MEAS_FILTER_TRANSIENT_WAVEFORM_PERCENT = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 34)
NISCOPE_ATTR_MEAS_FILTER_TYPE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 35)
NISCOPE_ATTR_MEAS_FILTER_WIDTH = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 41)
NISCOPE_ATTR_MEAS_FIR_FILTER_WINDOW = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 42)
NISCOPE_ATTR_MEAS_HIGH_REF = IVISCOPE_ATTR_MEAS_HIGH_REF
NISCOPE_ATTR_MEAS_HYSTERESIS_PERCENT = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 19)
NISCOPE_ATTR_MEAS_INTERPOLATION_SAMPLING_FACTOR = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 30)
NISCOPE_ATTR_MEAS_LAST_ACQ_HISTOGRAM_SIZE = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 20)
NISCOPE_ATTR_MEAS_LOW_REF = IVISCOPE_ATTR_MEAS_LOW_REF
NISCOPE_ATTR_MEAS_MID_REF = IVISCOPE_ATTR_MEAS_MID_REF
NISCOPE_ATTR_MEAS_OTHER_CHANNEL = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 18)
NISCOPE_ATTR_MEAS_PERCENTAGE_METHOD = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 45)
NISCOPE_ATTR_MEAS_POLYNOMIAL_INTERPOLATION_ORDER = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 29)
NISCOPE_ATTR_MEAS_REF_LEVEL_UNITS = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 16)
NISCOPE_ATTR_MEAS_TIME_HISTOGRAM_HIGH_TIME = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 28)
NISCOPE_ATTR_MEAS_TIME_HISTOGRAM_HIGH_VOLTS = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 26)
NISCOPE_ATTR_MEAS_TIME_HISTOGRAM_LOW_TIME = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 27)
NISCOPE_ATTR_MEAS_TIME_HISTOGRAM_LOW_VOLTS = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 25)
NISCOPE_ATTR_MEAS_TIME_HISTOGRAM_SIZE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 24)
NISCOPE_ATTR_MEAS_VOLTAGE_HISTOGRAM_HIGH_VOLTS = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 23)
NISCOPE_ATTR_MEAS_VOLTAGE_HISTOGRAM_LOW_VOLTS = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 22)
NISCOPE_ATTR_MEAS_VOLTAGE_HISTOGRAM_SIZE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 21)
NISCOPE_ATTR_MIN_SAMPLE_RATE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 9)
NISCOPE_ATTR_NUM_CHANNELS = NISCOPE_ATTR_CHANNEL_COUNT
NISCOPE_ATTR_ONBOARD_MEMORY_SIZE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 69)
NISCOPE_ATTR_OSCILLATOR_PHASE_DAC_VALUE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 105)
NISCOPE_ATTR_OUTPUT_CLOCK_SOURCE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 3)
NISCOPE_ATTR_PFI1_TRIGGER_OUTPUT_EVENT = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 61)
NISCOPE_ATTR_PFI2_TRIGGER_OUTPUT_EVENT = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 62)
NISCOPE_ATTR_PLL_LOCK_STATUS = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1303)
NISCOPE_ATTR_POINTS_DONE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 82)
NISCOPE_ATTR_POLL_INTERVAL = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 100)
NISCOPE_ATTR_PRIMARY_ERROR = IVI_ATTR_PRIMARY_ERROR
NISCOPE_ATTR_PROBE_ATTENUATION = IVISCOPE_ATTR_PROBE_ATTENUATION
NISCOPE_ATTR_QUERY_INSTR_STATUS = NISCOPE_ATTR_QUERY_INSTRUMENT_STATUS
NISCOPE_ATTR_RANGE_CHECK = IVI_ATTR_RANGE_CHECK
NISCOPE_ATTR_READY_FOR_ADVANCE_EVENT_OUTPUT_TERMINAL = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 112)
NISCOPE_ATTR_READY_FOR_REF_EVENT_OUTPUT_TERMINAL = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 111)
NISCOPE_ATTR_READY_FOR_START_EVENT_OUTPUT_TERMINAL = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 110)
NISCOPE_ATTR_RECORD_ARM_SOURCE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 65)
NISCOPE_ATTR_RECORD_COERCIONS = IVI_ATTR_RECORD_COERCIONS
NISCOPE_ATTR_RECORDS_DONE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 83)
NISCOPE_ATTR_REF_CLK_RATE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 90)
NISCOPE_ATTR_REF_TRIG_TDC_ENABLE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 96)
NISCOPE_ATTR_RESOLUTION = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 102)
NISCOPE_ATTR_RESOURCE_DESCRIPTOR = NISCOPE_ATTR_IO_RESOURCE_DESCRIPTOR
NISCOPE_ATTR_RETURN_DEFERRED_VALUES = IVI_ATTR_RETURN_DEFERRED_VALUES
NISCOPE_ATTR_RIS_IN_AUTO_SETUP_ENABLE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 106)
NISCOPE_ATTR_RIS_METHOD = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 71)
NISCOPE_ATTR_RIS_NUM_AVERAGES = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 70)
NISCOPE_ATTR_RTSI0_TRIGGER_OUTPUT_EVENT = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 54)
NISCOPE_ATTR_RTSI1_TRIGGER_OUTPUT_EVENT = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 55)
NISCOPE_ATTR_RTSI2_TRIGGER_OUTPUT_EVENT = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 56)
NISCOPE_ATTR_RTSI3_TRIGGER_OUTPUT_EVENT = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 57)
NISCOPE_ATTR_RTSI4_TRIGGER_OUTPUT_EVENT = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 58)
NISCOPE_ATTR_RTSI5_TRIGGER_OUTPUT_EVENT = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 59)
NISCOPE_ATTR_RTSI6_TRIGGER_OUTPUT_EVENT = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 60)
NISCOPE_ATTR_SAMP_CLK_TIMEBASE_DIV = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 89)
NISCOPE_ATTR_SAMP_CLK_TIMEBASE_RATE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 88)
NISCOPE_ATTR_SAMP_CLK_TIMEBASE_SRC = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 87)
NISCOPE_ATTR_SAMPLE_MODE = IVISCOPE_ATTR_SAMPLE_MODE
NISCOPE_ATTR_SECONDARY_ERROR = IVI_ATTR_SECONDARY_ERROR
NISCOPE_ATTR_SERIAL_DAC_CAL_VOLTAGE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1302)
NISCOPE_ATTR_SERIAL_NUMBER = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 104)
NISCOPE_ATTR_SIMULATE = IVI_ATTR_SIMULATE
NISCOPE_ATTR_SLAVE_TRIGGER_DELAY = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 46)
NISCOPE_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION = IVI_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION
NISCOPE_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION = IVI_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION
NISCOPE_ATTR_SPECIFIC_DRIVER_DESCRIPTION = IVI_ATTR_SPECIFIC_DRIVER_DESCRIPTION
NISCOPE_ATTR_SPECIFIC_DRIVER_PREFIX = IVI_ATTR_SPECIFIC_DRIVER_PREFIX
NISCOPE_ATTR_SPECIFIC_DRIVER_VENDOR = IVI_ATTR_SPECIFIC_DRIVER_VENDOR
NISCOPE_ATTR_SPECIFIC_PREFIX = NISCOPE_ATTR_SPECIFIC_DRIVER_PREFIX
NISCOPE_ATTR_STAR_TRIGGER_OUTPUT_EVENT = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 63)
NISCOPE_ATTR_START_TO_REF_TRIGGER_HOLDOFF = (
    IVI_SPECIFIC_PUBLIC_ATTR_BASE + 103)
NISCOPE_ATTR_SUPPORTED_INSTRUMENT_MODELS = IVI_ATTR_SUPPORTED_INSTRUMENT_MODELS
NISCOPE_ATTR_TRIGGER_COUPLING = IVISCOPE_ATTR_TRIGGER_COUPLING
NISCOPE_ATTR_TRIGGER_DELAY_TIME = IVISCOPE_ATTR_TRIGGER_DELAY_TIME
NISCOPE_ATTR_TRIGGER_FROM_PFI_DELAY = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 52)
NISCOPE_ATTR_TRIGGER_FROM_RTSI_DELAY = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 51)
NISCOPE_ATTR_TRIGGER_FROM_STAR_DELAY = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 50)
NISCOPE_ATTR_TRIGGER_HOLDOFF = IVISCOPE_ATTR_TRIGGER_HOLDOFF
NISCOPE_ATTR_TRIGGER_HYSTERESIS = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 6)
NISCOPE_ATTR_TRIGGER_IMPEDANCE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 75)
NISCOPE_ATTR_TRIGGER_LEVEL = IVISCOPE_ATTR_TRIGGER_LEVEL
NISCOPE_ATTR_TRIGGER_OUTPUT_EVENT = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 10)
NISCOPE_ATTR_TRIGGER_OUTPUT_SOURCE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 11)
NISCOPE_ATTR_TRIGGER_SLOPE = IVISCOPE_ATTR_TRIGGER_SLOPE
NISCOPE_ATTR_TRIGGER_SOURCE = IVISCOPE_ATTR_TRIGGER_SOURCE
NISCOPE_ATTR_TRIGGER_TO_PFI_DELAY = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 49)
NISCOPE_ATTR_TRIGGER_TO_RTSI_DELAY = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 48)
NISCOPE_ATTR_TRIGGER_TO_STAR_DELAY = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 47)
NISCOPE_ATTR_TRIGGER_TYPE = IVISCOPE_ATTR_TRIGGER_TYPE
NISCOPE_ATTR_TRIGGER_WINDOW_HIGH_LEVEL = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 14)
NISCOPE_ATTR_TRIGGER_WINDOW_LOW_LEVEL = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 13)
NISCOPE_ATTR_TRIGGER_WINDOW_MODE = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 12)
NISCOPE_ATTR_TV_TRIGGER_EVENT = IVISCOPE_ATTR_TV_TRIGGER_EVENT
NISCOPE_ATTR_TV_TRIGGER_LINE_NUMBER = IVISCOPE_ATTR_TV_TRIGGER_LINE_NUMBER
NISCOPE_ATTR_TV_TRIGGER_POLARITY = IVISCOPE_ATTR_TV_TRIGGER_POLARITY
NISCOPE_ATTR_TV_TRIGGER_SIGNAL_FORMAT = IVISCOPE_ATTR_TV_TRIGGER_SIGNAL_FORMAT
NISCOPE_ATTR_USE_SPEC_INITIAL_X = (IVI_SPECIFIC_PUBLIC_ATTR_BASE + 67)
NISCOPE_ATTR_VERTICAL_COUPLING = IVISCOPE_ATTR_VERTICAL_COUPLING
NISCOPE_ATTR_VERTICAL_OFFSET = IVISCOPE_ATTR_VERTICAL_OFFSET
NISCOPE_ATTR_VERTICAL_RANGE = IVISCOPE_ATTR_VERTICAL_RANGE
NISCOPE_ERRMSG_ACQ_IN_PROGRESS = "A previous acquisition is still in progress. If you are attempting to change an attribute, note you can only change fetch attributes while an acquisition is still in progress."
NISCOPE_ERRMSG_ADC_CAL_FAILURE = "ADC exceeds linearity specs"
NISCOPE_ERRMSG_ATTRIBUTES_DIFFER_BY_CHANNEL = "Getting an attribute value failed because the queried channels have different values."
NISCOPE_ERRMSG_BAD_MEASUREMENT = "The specified waveform measurement is not allowed with this function."
NISCOPE_ERRMSG_BUFFER_NOT_ACQUIRED = "Requested buffer has not been acquired yet."
NISCOPE_ERRMSG_CHANNEL_NAME_TOO_LONG = "The channel name is too long."
NISCOPE_ERRMSG_CREATE_THREAD = "Acquisition thread could not be created."
NISCOPE_ERRMSG_DATA_NOT_AVAILABLE = "Data acquired during the acquisition is not available."
NISCOPE_ERRMSG_DATA_OVERWRITTEN = "The requested data has been overwritten in memory so it is no longer available for fetching."
NISCOPE_ERRMSG_DIGITIZER_ALREADY_IN_USE = "The digitizer is being used by another application or process."
NISCOPE_ERRMSG_DMA_CONFIG_ERROR = "DMA config error."
NISCOPE_ERRMSG_EXT_CAL_CONSTS_INVALID = "External calibration constants are invalid.  Perform an external calibration. Contact National Instruments if you need additional information."
NISCOPE_ERRMSG_EXT_CAL_NOT_COMPLETE = "Attempt to store calibration constants without completing all the necessary external calibration steps.Consult the calibration procedure. Verify that all necessary steps are performed before closing the external calibration session."
NISCOPE_ERRMSG_FLEXRES_CONFIG_CORRUPT = "The FlexRes configuration files are corrupt, please reinstall niscope software or contact National Instruments."
NISCOPE_ERRMSG_GAIN_CAL_FAILURE = "Unable to perform gain calibration"
NISCOPE_ERRMSG_GAIN_OFFSET_CAL_FAILURE = "Unable to perform gain/offset calibration."
NISCOPE_ERRMSG_HARDWARE_FAILURE = "Hardware failure occurred during operation."
NISCOPE_ERRMSG_HEATER_CIRCUIT_CAL_FAILURE = "Unable to calibrate onboard temperature stablization circuit."
NISCOPE_ERRMSG_HOLDOFF_DELAY_NONZERO = "Specifying either trigger holdoff or trigger delay is allowed, but not both."
NISCOPE_ERRMSG_ILLEGAL_DATATYPE = "Illegal data type parameter. See niscope.h for legal defined values."
NISCOPE_ERRMSG_ILLEGAL_RELATIVE_TO = "Illegal relativeTo parameter."
NISCOPE_ERRMSG_ILLEGAL_USER_OFFSET = "The user offset specified is not valid."
NISCOPE_ERRMSG_INITIATE_NOT_CALLED = "An acquisition has not been initiated."
NISCOPE_ERRMSG_INSUFFICIENT_MEMORY = "Insufficient on-board memory available to perform the acquisition."
NISCOPE_ERRMSG_INVALID_CAL_SESSION = "This function requires an external calibration session. Call niScope_CalStart instead of niScope_init to get the proper session type."
NISCOPE_ERRMSG_INVALID_DATA = "Data acquired during the acquisition is invalid."
NISCOPE_ERRMSG_INVALID_FETCH_PARAMETERS = "The fetch parameters are not valid."
NISCOPE_ERRMSG_INVALID_FUNCTION_USE = "This function may not be used for fetching multiple waveforms, or when the acquisition type is DDC."
NISCOPE_ERRMSG_INVALID_GAIN = "Invalid gain specified. Use the gain constants defined in the calibration header file."
NISCOPE_ERRMSG_INVALID_RIS_METHOD = "RIS method is invalid."
NISCOPE_ERRMSG_INVALID_RIS_NUM_AVERAGES = "RIS num averages attribute is invalid. It must be greater than 0."
NISCOPE_ERRMSG_INVALID_TIMESTAMP_EVENT_TAG = "Invalid timestamp event tag."
NISCOPE_ERRMSG_LIN_CAL_FAILURE = "Unable to calculate linearity coefficients"
NISCOPE_ERRMSG_PAR_TO_SER_CONV_FAILURE = "Parallel to serial convertor failure."
NISCOPE_ERRMSG_PLL_FAILURE = "PLL failure."
NISCOPE_ERRMSG_RIS_DID_NOT_COMPLETE = "RIS did not complete so data is not available."
NISCOPE_ERRMSG_SIM_MODEL_NOT_SUPPORTED = "Simulation does not support the selected model and board type."
NISCOPE_ERRMSG_SINE_CAL_FAILURE = "Unable to acquire valid sine wave for calibration"
NISCOPE_ERRMSG_SOFTWARE_FAILURE = "Software failure occurred during operation."
NISCOPE_ERRMSG_SPECIFICDLL_GET_ADDRESS_FAILURE = "An exported function address could not be obtained from the specific niScopeDAQ or niScopeDMF dll."
NISCOPE_ERRMSG_SPECIFICDLL_LOAD_FAILURE = "The specific niScopeDAQ or niScopeDMF dll could not be loaded."
NISCOPE_ERRMSG_TIMEOUT_CHECKING_STATUS = "Timeout checking status."
NISCOPE_ERRMSG_TIMEOUT_CLEARING_TIO = "Timeout clearing TIO."
NISCOPE_ERRMSG_TIMEOUT_TRANSFERRING_DATA = "Timeout transferring data."
NISCOPE_ERRMSG_TIMEOUT_TRANSFERRING_TIMESTAMPS = "Timeout transferring timestamps."
NISCOPE_ERRMSG_TRIGGER_DELAY_INVALID_WITH_RIS = "The trigger delay parameter to the configure trigger function must be zero during RIS acquisitions."
NISCOPE_ERRMSG_TRIGGER_HAS_NOT_OCCURRED = "The trigger has not occurred for the requested buffer, so data cannot be fetched relative to the trigger."
NISCOPE_ERRMSG_TRIGGER_TYPE_INVALID = "The configure trigger type is invalid or not supported"
NISCOPE_ERRMSG_WRONG_PASSWORD = "Password in EEPROM does not match the given password."
NISCOPE_ERROR_ACQ_IN_PROGRESS = (IVI_SPECIFIC_ERROR_BASE + 0x009)
NISCOPE_ERROR_ADC_CAL_FAILURE = (IVI_SPECIFIC_ERROR_BASE + 0x008)
NISCOPE_ERROR_ATTRIBUTES_DIFFER_BY_CHANNEL = (IVI_SPECIFIC_ERROR_BASE + 0x028)
NISCOPE_ERROR_BAD_MEASUREMENT = (IVI_SPECIFIC_ERROR_BASE + 0x014)
NISCOPE_ERROR_BUFFER_NOT_ACQUIRED = (IVI_SPECIFIC_ERROR_BASE + 0x015)
NISCOPE_ERROR_CHANNEL_NAME_TOO_LONG = (IVI_SPECIFIC_ERROR_BASE + 0x02D)
NISCOPE_ERROR_CHANNEL_NOT_ENABLED = IVISCOPE_ERROR_CHANNEL_NOT_ENABLED
NISCOPE_ERROR_CREATE_THREAD = (IVI_SPECIFIC_ERROR_BASE + 0x00E)
NISCOPE_ERROR_DATA_NOT_AVAILABLE = (IVI_SPECIFIC_ERROR_BASE + 0x00A)
NISCOPE_ERROR_DATA_OVERWRITTEN = (IVI_SPECIFIC_ERROR_BASE + 0x018)
NISCOPE_ERROR_DIGITIZER_ALREADY_IN_USE = (IVI_SPECIFIC_ERROR_BASE + 0x02E)
NISCOPE_ERROR_DMA_CONFIG_ERROR = (IVI_SPECIFIC_ERROR_BASE + 0x020)
NISCOPE_ERROR_EXT_CAL_CONSTS_INVALID = (IVI_SPECIFIC_ERROR_BASE + 0X035)
NISCOPE_ERROR_EXT_CAL_NOT_COMPLETE = (IVI_SPECIFIC_ERROR_BASE + 0X034)
NISCOPE_ERROR_FLEXRES_CONFIG_CORRUPT = (IVI_SPECIFIC_ERROR_BASE + 0x00C)
NISCOPE_ERROR_GAIN_CAL_FAILURE = (IVI_SPECIFIC_ERROR_BASE + 0x005)
NISCOPE_ERROR_GAIN_OFFSET_CAL_FAILURE = (IVI_SPECIFIC_ERROR_BASE + 0x00D)
NISCOPE_ERROR_HARDWARE_FAILURE = (IVI_SPECIFIC_ERROR_BASE + 0x002)
NISCOPE_ERROR_HEATER_CIRCUIT_CAL_FAILURE = (IVI_SPECIFIC_ERROR_BASE + 0x00B)
NISCOPE_ERROR_HOLDOFF_DELAY_NONZERO = (IVI_SPECIFIC_ERROR_BASE + 0x02C)
NISCOPE_ERROR_ILLEGAL_DATATYPE = (IVI_SPECIFIC_ERROR_BASE + 0x027)
NISCOPE_ERROR_ILLEGAL_RELATIVE_TO = (IVI_SPECIFIC_ERROR_BASE + 0x017)
NISCOPE_ERROR_ILLEGAL_USER_OFFSET = (IVI_SPECIFIC_ERROR_BASE + 0x021)
NISCOPE_ERROR_INITIATE_NOT_CALLED = (IVI_SPECIFIC_ERROR_BASE + 0x02A)
NISCOPE_ERROR_INSUFFICIENT_MEMORY = (IVI_SPECIFIC_ERROR_BASE + 0x003)
NISCOPE_ERROR_INVALID_CAL_SESSION = (IVI_SPECIFIC_ERROR_BASE + 0x013)
NISCOPE_ERROR_INVALID_DATA = (IVI_SPECIFIC_ERROR_BASE + 0x004)
NISCOPE_ERROR_INVALID_FETCH_PARAMETERS = (IVI_SPECIFIC_ERROR_BASE + 0X033)
NISCOPE_ERROR_INVALID_FUNCTION_USE = (IVI_SPECIFIC_ERROR_BASE + 0x02B)
NISCOPE_ERROR_INVALID_GAIN = (IVI_SPECIFIC_ERROR_BASE + 0x010)
NISCOPE_ERROR_INVALID_RIS_METHOD = (IVI_SPECIFIC_ERROR_BASE + 0x025)
NISCOPE_ERROR_INVALID_RIS_NUM_AVERAGES = (IVI_SPECIFIC_ERROR_BASE + 0x026)
NISCOPE_ERROR_INVALID_SESSION = 0xBFFA1190
NISCOPE_ERROR_INVALID_TIMESTAMP_EVENT_TAG = (IVI_SPECIFIC_ERROR_BASE + 0x01A)
NISCOPE_ERROR_LIN_CAL_FAILURE = (IVI_SPECIFIC_ERROR_BASE + 0x007)
NISCOPE_ERROR_MAX_TIME_EXCEEDED = IVISCOPE_ERROR_MAX_TIME_EXCEEDED
NISCOPE_ERROR_NOT_A_SCOPE = (IVI_SPECIFIC_ERROR_BASE + 0x022)
NISCOPE_ERROR_PAR_TO_SER_CONV_FAILURE = (IVI_SPECIFIC_ERROR_BASE + 0x01F)
NISCOPE_ERROR_PLL_FAILURE = (IVI_SPECIFIC_ERROR_BASE + 0x01E)
NISCOPE_ERROR_RIS_DID_NOT_COMPLETE = (IVI_SPECIFIC_ERROR_BASE + 0x024)
NISCOPE_ERROR_SIM_MODEL_NOT_SUPPORTED = (IVI_SPECIFIC_ERROR_BASE + 0X02F)
NISCOPE_ERROR_SINE_CAL_FAILURE = (IVI_SPECIFIC_ERROR_BASE + 0x006)
NISCOPE_ERROR_SOFTWARE_FAILURE = (IVI_SPECIFIC_ERROR_BASE + 0x001)
NISCOPE_ERROR_SPECIFICDLL_GET_ADDRESS_FAILURE = (
    IVI_SPECIFIC_ERROR_BASE + 0X031)
NISCOPE_ERROR_SPECIFICDLL_LOAD_FAILURE = (IVI_SPECIFIC_ERROR_BASE + 0X030)
NISCOPE_ERROR_TIMEOUT_CHECKING_STATUS = (IVI_SPECIFIC_ERROR_BASE + 0x01C)
NISCOPE_ERROR_TIMEOUT_CLEARING_TIO = (IVI_SPECIFIC_ERROR_BASE + 0x023)
NISCOPE_ERROR_TIMEOUT_TRANSFERRING_DATA = (IVI_SPECIFIC_ERROR_BASE + 0x01D)
NISCOPE_ERROR_TIMEOUT_TRANSFERRING_TIMESTAMPS = (
    IVI_SPECIFIC_ERROR_BASE + 0x01B)
NISCOPE_ERROR_TRIGGER_DELAY_INVALID_WITH_RIS = (
    IVI_SPECIFIC_ERROR_BASE + 0x029)
NISCOPE_ERROR_TRIGGER_HAS_NOT_OCCURRED = (IVI_SPECIFIC_ERROR_BASE + 0x016)
NISCOPE_ERROR_TRIGGER_TYPE_INVALID = (IVI_SPECIFIC_ERROR_BASE + 0X032)
NISCOPE_ERROR_UNABLE_TO_PERFORM_MEASUREMENT = IVISCOPE_ERROR_UNABLE_TO_PERFORM_MEASUREMENT
NISCOPE_ERROR_WRONG_PASSWORD = (IVI_SPECIFIC_ERROR_BASE + 0x00F)
NISCOPE_INVALID_WFM_VOLTAGE = IVISCOPE_VAL_INVALID_WFM_VOLTAGE
NISCOPE_MAJOR_VERSION = 2
NISCOPE_MAX_VALID_WFM_VOLTAGE = IVISCOPE_VAL_MAX_VALID_WFM_VOLTAGE
NISCOPE_MINOR_VERSION = 900
NISCOPE_VAL_100MHZ_BANDWIDTH = 100000000.0
NISCOPE_VAL_100MHZ_MAX_INPUT_FREQUENCY = 100000000.0
NISCOPE_VAL_1080I_50_FIELDS_PER_SECOND = (
    IVISCOPE_VAL_TV_SIGNAL_FORMAT_SPECIFIC_EXT_BASE + 40)
NISCOPE_VAL_1080I_59_94_FIELDS_PER_SECOND = (
    IVISCOPE_VAL_TV_SIGNAL_FORMAT_SPECIFIC_EXT_BASE + 41)
NISCOPE_VAL_1080I_60_FIELDS_PER_SECOND = (
    IVISCOPE_VAL_TV_SIGNAL_FORMAT_SPECIFIC_EXT_BASE + 42)
NISCOPE_VAL_1080P_24_FRAMES_PER_SECOND = (
    IVISCOPE_VAL_TV_SIGNAL_FORMAT_SPECIFIC_EXT_BASE + 45)
NISCOPE_VAL_16_TAP_HANNING = 2
NISCOPE_VAL_1_MEG_OHM = IVISCOPE_VAL_1_MEG_OHM
NISCOPE_VAL_20MHZ_BANDWIDTH = 20000000.0
NISCOPE_VAL_20MHZ_MAX_INPUT_FREQUENCY = 20000000.0
NISCOPE_VAL_480I_59_94_FIELDS_PER_SECOND = (
    IVISCOPE_VAL_TV_SIGNAL_FORMAT_SPECIFIC_EXT_BASE + 10)
NISCOPE_VAL_480I_60_FIELDS_PER_SECOND = (
    IVISCOPE_VAL_TV_SIGNAL_FORMAT_SPECIFIC_EXT_BASE + 11)
NISCOPE_VAL_480P_59_94_FRAMES_PER_SECOND = (
    IVISCOPE_VAL_TV_SIGNAL_FORMAT_SPECIFIC_EXT_BASE + 15)
NISCOPE_VAL_480P_60_FRAMES_PER_SECOND = (
    IVISCOPE_VAL_TV_SIGNAL_FORMAT_SPECIFIC_EXT_BASE + 16)
NISCOPE_VAL_48_TAP_HANNING = 1
NISCOPE_VAL_48_TAP_STANDARD = 0
NISCOPE_VAL_50_OHMS = IVISCOPE_VAL_50_OHMS
NISCOPE_VAL_576I_50_FIELDS_PER_SECOND = (
    IVISCOPE_VAL_TV_SIGNAL_FORMAT_SPECIFIC_EXT_BASE + 20)
NISCOPE_VAL_576P_50_FRAMES_PER_SECOND = (
    IVISCOPE_VAL_TV_SIGNAL_FORMAT_SPECIFIC_EXT_BASE + 25)
NISCOPE_VAL_720P_50_FRAMES_PER_SECOND = (
    IVISCOPE_VAL_TV_SIGNAL_FORMAT_SPECIFIC_EXT_BASE + 31)
NISCOPE_VAL_720P_59_94_FRAMES_PER_SECOND = (
    IVISCOPE_VAL_TV_SIGNAL_FORMAT_SPECIFIC_EXT_BASE + 32)
NISCOPE_VAL_720P_60_FRAMES_PER_SECOND = (
    IVISCOPE_VAL_TV_SIGNAL_FORMAT_SPECIFIC_EXT_BASE + 33)
NISCOPE_VAL_75_OHMS = IVISCOPE_VAL_75_OHMS
NISCOPE_VAL_8_TAP_HANNING = 3
NISCOPE_VAL_AC_ESTIMATE = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 12)
NISCOPE_VAL_AC = IVISCOPE_VAL_AC
NISCOPE_VAL_AC_PLUS_HF_REJECT = (
    IVISCOPE_VAL_TRIGGER_COUPLING_SPECIFIC_EXT_BASE + 1)
NISCOPE_VAL_ACQ_COMPLETE = IVISCOPE_VAL_ACQ_COMPLETE
NISCOPE_VAL_ACQ_IN_PROGRESS = IVISCOPE_VAL_ACQ_IN_PROGRESS
NISCOPE_VAL_ACQ_STATUS_UNKNOWN = IVISCOPE_VAL_ACQ_STATUS_UNKNOWN
NISCOPE_VAL_ADD_CHANNELS = 4013
NISCOPE_VAL_ADVANCE_TRIGGER = 5
NISCOPE_VAL_ALL_MEASUREMENTS = 10000
NISCOPE_VAL_AMPLITUDE = IVISCOPE_VAL_AMPLITUDE
NISCOPE_VAL_AREA = (IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 3)
NISCOPE_VAL_ARRAY_GAIN = 4026
NISCOPE_VAL_ARRAY_INTEGRAL = 4006
NISCOPE_VAL_ARRAY_OFFSET = 4025
NISCOPE_VAL_ASYMMETRIC = 1
NISCOPE_VAL_AUTO = IVISCOPE_VAL_AUTO
NISCOPE_VAL_AUTO_LEVEL = IVISCOPE_VAL_AUTO_LEVEL
NISCOPE_VAL_AVERAGE_FREQUENCY = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 16)
NISCOPE_VAL_AVERAGE_PERIOD = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 15)
NISCOPE_VAL_BANDWIDTH_DEVICE_DEFAULT = 0.0
NISCOPE_VAL_BANDWIDTH_FULL = -1.0
NISCOPE_VAL_BESSEL_FILTER = 4022
NISCOPE_VAL_BLACKMAN_WINDOW = 4024
NISCOPE_VAL_BUTTERWORTH_FILTER = 4017
NISCOPE_VAL_CAL_RESTORE_EXTERNAL_CALIBRATION = NISCOPE_VAL_RESTORE_FACTORY_CALIBRATION
NISCOPE_VAL_CHEBYSHEV_FILTER = 4018
NISCOPE_VAL_CLEAR_EEPROM = 101
NISCOPE_VAL_CLK_IN = "VAL_CLK_IN"
NISCOPE_VAL_CLK_OUT = "VAL_CLK_OUT"
NISCOPE_VAL_COMPLEX = 1
NISCOPE_VAL_CYCLE_AREA = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 4)
NISCOPE_VAL_DC_ESTIMATE = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 13)
NISCOPE_VAL_DC = IVISCOPE_VAL_DC
NISCOPE_VAL_DDC = (IVISCOPE_VAL_ACQUISITION_TYPE_SPECIFIC_EXT_BASE + 2)
NISCOPE_VAL_DERIVATIVE = 4007
NISCOPE_VAL_DIFFERENTIAL = 2
NISCOPE_VAL_DIGITAL = (IVISCOPE_VAL_TRIGGER_TYPE_SPECIFIC_EXT_BASE + 2)
NISCOPE_VAL_DISCRIMINATOR_FIR_COEFFICIENTS = 1
NISCOPE_VAL_DIVIDE_CHANNELS = 4015
NISCOPE_VAL_DUTY_CYCLE_NEG = IVISCOPE_VAL_DUTY_CYCLE_NEG
NISCOPE_VAL_DUTY_CYCLE_POS = IVISCOPE_VAL_DUTY_CYCLE_POS
NISCOPE_VAL_ECL0 = IVISCOPE_VAL_ECL0
NISCOPE_VAL_ECL1 = IVISCOPE_VAL_ECL1
NISCOPE_VAL_EDGE = IVISCOPE_VAL_EDGE_TRIGGER
NISCOPE_VAL_END_OF_ACQUISITION_EVENT = 3
NISCOPE_VAL_END_OF_RECORD_EVENT = 4
NISCOPE_VAL_ENTERING_WINDOW = 0
NISCOPE_VAL_EQUIVALENT_TIME = IVISCOPE_VAL_EQUIVALENT_TIME
NISCOPE_VAL_EVEN = 0
NISCOPE_VAL_EXTERNAL_CALIBRATION = 1
NISCOPE_VAL_EXTERNAL = IVISCOPE_VAL_EXTERNAL
NISCOPE_VAL_FALL_SLEW_RATE = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 11)
NISCOPE_VAL_FALL_TIME = IVISCOPE_VAL_FALL_TIME
NISCOPE_VAL_FALSE = (VI_FALSE)
NISCOPE_VAL_FFT_AMPLITUDE = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 9)
NISCOPE_VAL_FFT_AMP_SPECTRUM_DB = 4019
NISCOPE_VAL_FFT_AMP_SPECTRUM_VOLTS_RMS = 4003
NISCOPE_VAL_FFT_FREQUENCY = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 8)
NISCOPE_VAL_FFT_PHASE_SPECTRUM = 4002
NISCOPE_VAL_FLAT_TOP_WINDOW = 4010
NISCOPE_VAL_FLEXRES = (IVISCOPE_VAL_ACQUISITION_TYPE_SPECIFIC_EXT_BASE + 1)
NISCOPE_VAL_FREQ_DATA = 2
NISCOPE_VAL_FREQUENCY = IVISCOPE_VAL_FREQUENCY
NISCOPE_VAL_FULL_BANDWIDTH = 0.0
NISCOPE_VAL_GND = IVISCOPE_VAL_GND
NISCOPE_VAL_HAMMING_WINDOW = 4020
NISCOPE_VAL_HANNING_WINDOW = 4009
NISCOPE_VAL_HF_REJECT = IVISCOPE_VAL_HF_REJECT
NISCOPE_VAL_HIGH_REF_VOLTS = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 2)
NISCOPE_VAL_HYSTERESIS = (IVISCOPE_VAL_TRIGGER_TYPE_SPECIFIC_EXT_BASE + 1)
NISCOPE_VAL_I_DATA = 0
NISCOPE_VAL_IMMEDIATE = IVISCOPE_VAL_IMMEDIATE
NISCOPE_VAL_IMMEDIATE_TRIGGER = IVISCOPE_VAL_IMMEDIATE_TRIGGER
NISCOPE_VAL_INPUT = 0
NISCOPE_VAL_INTEGRAL = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 5)
NISCOPE_VAL_INTERNAL10MHZ_OSC = "VAL_INTERNAL10MHZ_OSC"
NISCOPE_VAL_INVERSE = 4008
NISCOPE_VAL_LAST_ACQ_HISTOGRAM = 4001
NISCOPE_VAL_LEAVING_WINDOW = 1
NISCOPE_VAL_LF_REJECT = IVISCOPE_VAL_LF_REJECT
NISCOPE_VAL_LINEAR = IVISCOPE_VAL_LINEAR
NISCOPE_VAL_LOW_REF_VOLTS = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 0)
NISCOPE_VAL_MAGNITUDE = 1
NISCOPE_VAL_MAGNITUDE_DATA = 1
NISCOPE_VAL_MAX_TIME_IMMEDIATE = IVISCOPE_VAL_MAX_TIME_IMMEDIATE
NISCOPE_VAL_MAX_TIME_INFINITE = IVISCOPE_VAL_MAX_TIME_INFINITE
NISCOPE_VAL_MAX_TIME_NONE = IVISCOPE_VAL_MAX_TIME_IMMEDIATE
NISCOPE_VAL_MEAS_BANDPASS = 2
NISCOPE_VAL_MEAS_BANDSTOP = 3
NISCOPE_VAL_MEAS_BASE_TOP = 2
NISCOPE_VAL_MEAS_HIGHPASS = 1
NISCOPE_VAL_MEAS_LOW_HIGH = 0
NISCOPE_VAL_MEAS_LOWPASS = 0
NISCOPE_VAL_MEAS_MIN_MAX = 1
NISCOPE_VAL_MEAS_PERCENTAGE = 1
NISCOPE_VAL_MEAS_VOLTAGE = 0
NISCOPE_VAL_MID_REF_VOLTS = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 1)
NISCOPE_VAL_M_PAL = (IVISCOPE_VAL_TV_SIGNAL_FORMAT_SPECIFIC_EXT_BASE + 1)
NISCOPE_VAL_MULTI_ACQ_AVERAGE = 4016
NISCOPE_VAL_MULTI_ACQ_TIME_HISTOGRAM = 4005
NISCOPE_VAL_MULTI_ACQ_VOLTAGE_HISTOGRAM = 4004
NISCOPE_VAL_MULTIPLY_CHANNELS = 4012
NISCOPE_VAL_NEGATIVE = IVISCOPE_VAL_NEGATIVE
NISCOPE_VAL_NO_EVENT = 0
NISCOPE_VAL_NO_INTERPOLATION = IVISCOPE_VAL_NO_INTERPOLATION
NISCOPE_VAL_NO_MEASUREMENT = 4000
NISCOPE_VAL_NONE = 0
NISCOPE_VAL_NORMAL = IVISCOPE_VAL_NORMAL
NISCOPE_VAL_NO_SOURCE = "VAL_NO_SOURCE"
NISCOPE_VAL_NO_TRIGGER_MOD = IVISCOPE_VAL_NO_TRIGGER_MOD
NISCOPE_VAL_NOW = 481
NISCOPE_VAL_NTSC = IVISCOPE_VAL_NTSC
NISCOPE_VAL_ODD = 1
NISCOPE_VAL_OUTPUT = 1
NISCOPE_VAL_OVERSHOOT = IVISCOPE_VAL_OVERSHOOT
NISCOPE_VAL_PAL = IVISCOPE_VAL_PAL
NISCOPE_VAL_PERIOD = IVISCOPE_VAL_PERIOD
NISCOPE_VAL_PFI_0 = "VAL_PFI_0"
NISCOPE_VAL_PFI_1 = "VAL_PFI_1"
NISCOPE_VAL_PFI_2 = "VAL_PFI_2"
NISCOPE_VAL_PFIR_COEFFICIENTS = 0
NISCOPE_VAL_PHASE = 0
NISCOPE_VAL_PHASE_DATA = 4
NISCOPE_VAL_PHASE_DELAY = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 18)
NISCOPE_VAL_POLYNOMIAL_INTERPOLATION = 4011
NISCOPE_VAL_POSITIVE = IVISCOPE_VAL_POSITIVE
NISCOPE_VAL_PRESHOOT = IVISCOPE_VAL_PRESHOOT
NISCOPE_VAL_PRETRIGGER = 477
NISCOPE_VAL_PXI_CLOCK = "VAL_PXI_CLOCK"
NISCOPE_VAL_PXI_STAR = IVISCOPE_VAL_PXI_STAR
NISCOPE_VAL_Q_DATA = 3
NISCOPE_VAL_READ_POINTER = 388
NISCOPE_VAL_READY_FOR_ADVANCE_EVENT = 6
NISCOPE_VAL_READY_FOR_REF_EVENT = 10
NISCOPE_VAL_READY_FOR_START_EVENT = 7
NISCOPE_VAL_REAL = 0
NISCOPE_VAL_REAL_TIME = IVISCOPE_VAL_REAL_TIME
NISCOPE_VAL_REF_CLOCK = 100
NISCOPE_VAL_REF_TRIGGER = 1
NISCOPE_VAL_RESAMPLER = 2
NISCOPE_VAL_RISE_SLEW_RATE = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 10)
NISCOPE_VAL_RISE_TIME = IVISCOPE_VAL_RISE_TIME
NISCOPE_VAL_RIS_EXACT_NUM_AVERAGES = 1
NISCOPE_VAL_RIS_INCOMPLETE = 3
NISCOPE_VAL_RIS_LIMITED_BIN_WIDTH = 5
NISCOPE_VAL_RIS_MIN_NUM_AVERAGES = 2
NISCOPE_VAL_RTSI_0 = IVISCOPE_VAL_RTSI_0
NISCOPE_VAL_RTSI_1 = IVISCOPE_VAL_RTSI_1
NISCOPE_VAL_RTSI_2 = IVISCOPE_VAL_RTSI_2
NISCOPE_VAL_RTSI_3 = IVISCOPE_VAL_RTSI_3
NISCOPE_VAL_RTSI_4 = IVISCOPE_VAL_RTSI_4
NISCOPE_VAL_RTSI_5 = IVISCOPE_VAL_RTSI_5
NISCOPE_VAL_RTSI_6 = IVISCOPE_VAL_RTSI_6
NISCOPE_VAL_RTSI_7 = "VAL_RTSI_7"
NISCOPE_VAL_RTSI_CLOCK = "VAL_RTSI_CLOCK"
NISCOPE_VAL_SAMPLE_CLOCK = 101
NISCOPE_VAL_SECAM = IVISCOPE_VAL_SECAM
NISCOPE_VAL_SELF_CALIBRATION = 0
NISCOPE_VAL_SINE_X = IVISCOPE_VAL_SINE_X
NISCOPE_VAL_SINGLE_ENDED = 0
NISCOPE_VAL_SOFTWARE_TRIGGER_ADVANCE = 3
NISCOPE_VAL_SOFTWARE_TRIGGER_ARM_REFERENCE = 1
NISCOPE_VAL_SOFTWARE_TRIGGER = (
    IVISCOPE_VAL_TRIGGER_TYPE_SPECIFIC_EXT_BASE + 4)
NISCOPE_VAL_SOFTWARE_TRIGGER_REFERENCE = 2
NISCOPE_VAL_SOFTWARE_TRIGGER_START = 0
NISCOPE_VAL_START = 482
NISCOPE_VAL_START_TRIGGER = 2
NISCOPE_VAL_START_TRIGGER_EVENT = 2
NISCOPE_VAL_STOP_TRIGGER_EVENT = 1
NISCOPE_VAL_SUBTRACT_CHANNELS = 4014
NISCOPE_VAL_SW_TRIG_FUNC = IVISCOPE_VAL_SW_TRIG_FUNC
NISCOPE_VAL_SYMMETRIC = 0
NISCOPE_VAL_TIME_DELAY = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 14)
NISCOPE_VAL_TIME_HISTOGRAM_HITS = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 2004)
NISCOPE_VAL_TIME_HISTOGRAM_MAX = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 2005)
NISCOPE_VAL_TIME_HISTOGRAM_MEAN = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 2000)
NISCOPE_VAL_TIME_HISTOGRAM_MEAN_PLUS_2_STDEV = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 2008)
NISCOPE_VAL_TIME_HISTOGRAM_MEAN_PLUS_3_STDEV = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 2009)
NISCOPE_VAL_TIME_HISTOGRAM_MEAN_PLUS_STDEV = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 2007)
NISCOPE_VAL_TIME_HISTOGRAM_MEDIAN = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 2003)
NISCOPE_VAL_TIME_HISTOGRAM_MIN = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 2006)
NISCOPE_VAL_TIME_HISTOGRAM_MODE = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 2010)
NISCOPE_VAL_TIME_HISTOGRAM_NEW_HITS = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 2011)
NISCOPE_VAL_TIME_HISTOGRAM_PEAK_TO_PEAK = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 2002)
NISCOPE_VAL_TIME_HISTOGRAM_STDEV = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 2001)
NISCOPE_VAL_TRIANGLE_WINDOW = 4023
NISCOPE_VAL_TRIGGER = 483
NISCOPE_VAL_TRUE = (VI_TRUE)
NISCOPE_VAL_TTL0 = IVISCOPE_VAL_TTL0
NISCOPE_VAL_TTL1 = IVISCOPE_VAL_TTL1
NISCOPE_VAL_TTL2 = IVISCOPE_VAL_TTL2
NISCOPE_VAL_TTL3 = IVISCOPE_VAL_TTL3
NISCOPE_VAL_TTL4 = IVISCOPE_VAL_TTL4
NISCOPE_VAL_TTL5 = IVISCOPE_VAL_TTL5
NISCOPE_VAL_TTL6 = IVISCOPE_VAL_TTL6
NISCOPE_VAL_TTL7 = IVISCOPE_VAL_TTL7
NISCOPE_VAL_TV_EVENT_ANY_FIELD = IVISCOPE_VAL_TV_EVENT_ANY_FIELD
NISCOPE_VAL_TV_EVENT_ANY_LINE = IVISCOPE_VAL_TV_EVENT_ANY_LINE
NISCOPE_VAL_TV_EVENT_FIELD1 = IVISCOPE_VAL_TV_EVENT_FIELD1
NISCOPE_VAL_TV_EVENT_FIELD2 = IVISCOPE_VAL_TV_EVENT_FIELD2
NISCOPE_VAL_TV_EVENT_LINE_NUMBER = IVISCOPE_VAL_TV_EVENT_LINE_NUMBER
NISCOPE_VAL_TV_NEGATIVE = IVISCOPE_VAL_TV_NEGATIVE
NISCOPE_VAL_TV_POSITIVE = IVISCOPE_VAL_TV_POSITIVE
NISCOPE_VAL_TV_TRIGGER = IVISCOPE_VAL_TV_TRIGGER
NISCOPE_VAL_UNBALANCED_DIFFERENTIAL = 1
NISCOPE_VAL_VOLTAGE_AVERAGE = IVISCOPE_VAL_VOLTAGE_AVERAGE
NISCOPE_VAL_VOLTAGE_BASE = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 6)
NISCOPE_VAL_VOLTAGE_BASE_TO_TOP = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 17)
NISCOPE_VAL_VOLTAGE_CYCLE_AVERAGE = IVISCOPE_VAL_VOLTAGE_CYCLE_AVERAGE
NISCOPE_VAL_VOLTAGE_CYCLE_RMS = IVISCOPE_VAL_VOLTAGE_CYCLE_RMS
NISCOPE_VAL_VOLTAGE_HIGH = IVISCOPE_VAL_VOLTAGE_HIGH
NISCOPE_VAL_VOLTAGE_HISTOGRAM_HITS = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 1004)
NISCOPE_VAL_VOLTAGE_HISTOGRAM_MAX = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 1005)
NISCOPE_VAL_VOLTAGE_HISTOGRAM_MEAN = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 1000)
NISCOPE_VAL_VOLTAGE_HISTOGRAM_MEAN_PLUS_2_STDEV = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 1008)
NISCOPE_VAL_VOLTAGE_HISTOGRAM_MEAN_PLUS_3_STDEV = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 1009)
NISCOPE_VAL_VOLTAGE_HISTOGRAM_MEAN_PLUS_STDEV = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 1007)
NISCOPE_VAL_VOLTAGE_HISTOGRAM_MEDIAN = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 1003)
NISCOPE_VAL_VOLTAGE_HISTOGRAM_MIN = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 1006)
NISCOPE_VAL_VOLTAGE_HISTOGRAM_MODE = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 1010)
NISCOPE_VAL_VOLTAGE_HISTOGRAM_NEW_HITS = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 1011)
NISCOPE_VAL_VOLTAGE_HISTOGRAM_PEAK_TO_PEAK = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 1002)
NISCOPE_VAL_VOLTAGE_HISTOGRAM_STDEV = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 1001)
NISCOPE_VAL_VOLTAGE_LOW = IVISCOPE_VAL_VOLTAGE_LOW
NISCOPE_VAL_VOLTAGE_MAX = IVISCOPE_VAL_VOLTAGE_MAX
NISCOPE_VAL_VOLTAGE_MIN = IVISCOPE_VAL_VOLTAGE_MIN
NISCOPE_VAL_VOLTAGE_PEAK_TO_PEAK = IVISCOPE_VAL_VOLTAGE_PEAK_TO_PEAK
NISCOPE_VAL_VOLTAGE_RMS = IVISCOPE_VAL_VOLTAGE_RMS
NISCOPE_VAL_VOLTAGE_TOP = (
    IVISCOPE_VAL_MEASUREMENT_FUNCTION_SPECIFIC_EXT_BASE + 7)
NISCOPE_VAL_WIDTH_NEG = IVISCOPE_VAL_WIDTH_NEG
NISCOPE_VAL_WIDTH_POS = IVISCOPE_VAL_WIDTH_POS
NISCOPE_VAL_WINDOWED_FIR_FILTER = 4021
NISCOPE_VAL_WINDOW = (IVISCOPE_VAL_TRIGGER_TYPE_SPECIFIC_EXT_BASE + 3)
NISCOPE_WARN_ADC_OVERLOAD = (IVI_SPECIFIC_WARN_BASE + 0x008)
NISCOPE_WARN_AUTOSETUP_NO_SIGNAL = (IVI_SPECIFIC_WARN_BASE + 0x004)
NISCOPE_WARN_CHANNEL_OVERLOAD = (IVI_SPECIFIC_WARN_BASE + 0x003)
NISCOPE_WARN_HEATER_CIRCUIT_TEMPERATURE = (IVI_SPECIFIC_WARN_BASE + 0x001)
NISCOPE_WARN_INVALID_DATA = (IVI_SPECIFIC_WARN_BASE + 0x002)
NISCOPE_WARN_INVALID_WFM_ELEMENT = IVISCOPE_WARN_INVALID_WFM_ELEMENT
NISCOPE_WARNMSG_ADC_OVERLOAD = "One or more channels has an ADC overload."
NISCOPE_WARNMSG_AUTOSETUP_NO_SIGNAL = "Auto Setup was unable to find a signal."
NISCOPE_WARNMSG_CHANNEL_OVERLOAD = "The 50 ohm protection on one or more channels has been disabled because of excess signal power."
NISCOPE_WARNMSG_HEATER_CIRCUIT_TEMPERATURE = "Onboard temperature stabilization circuit requires calibration."
NISCOPE_WARNMSG_INVALID_DATA = "Data acquired during the acquisition is possibly invalid. May be caused by high frequency transients or input voltage exceeding the maximum for given range."
NISCOPE_WARNMSG_PLL_UNLOCKED_AND_ADC_OVERLOAD = "The PLL is not locked and the ADC has an overload."
NISCOPE_WARNMSG_PLL_UNLOCKED = "The PLL is not locked."
NISCOPE_WARNMSG_TIMESTAMP_ROLLOVER = "The timestamp counter has rolled over."
NISCOPE_WARN_PLL_UNLOCKED_AND_ADC_OVERLOAD = (IVI_SPECIFIC_WARN_BASE + 0x006)
NISCOPE_WARN_PLL_UNLOCKED = (IVI_SPECIFIC_WARN_BASE + 0x005)
NISCOPE_WARN_TIMESTAMP_ROLLOVER = (IVI_SPECIFIC_WARN_BASE + 0x007)
VI_A16_SPACE = (1)
VI_A24_SPACE = (2)
VI_A32_SPACE = (3)
VI_A64_SPACE = (4)
VI_ALL_ENABLED_EVENTS = (0x3FFF7FFF)
VI_ALL_MECH = (0xFFFF)
VI_ANY_HNDLR = (0)
VI_ASRL488 = (VI_PROT_4882_STRS)
VI_ASRL_END_BREAK = (3)
VI_ASRL_END_LAST_BIT = (1)
VI_ASRL_END_NONE = (0)
VI_ASRL_END_TERMCHAR = (2)
VI_ASRL_FLOW_DTR_DSR = (4)
VI_ASRL_FLOW_NONE = (0)
VI_ASRL_FLOW_RTS_CTS = (2)
VI_ASRL_FLOW_XON_XOFF = (1)
VI_ASRL_IN_BUF_DISCARD = (VI_IO_IN_BUF_DISCARD)
VI_ASRL_IN_BUF = (VI_IO_IN_BUF)
VI_ASRL_OUT_BUF_DISCARD = (VI_IO_OUT_BUF_DISCARD)
VI_ASRL_OUT_BUF = (VI_IO_OUT_BUF)
VI_ASRL_PAR_EVEN = (2)
VI_ASRL_PAR_MARK = (3)
VI_ASRL_PAR_NONE = (0)
VI_ASRL_PAR_ODD = (1)
VI_ASRL_PAR_SPACE = (4)
VI_ASRL_STOP_ONE = (10)
VI_ASRL_STOP_ONE5 = (15)
VI_ASRL_STOP_TWO = (20)
VI_ASRL_WIRE_232_AUTO = (130)
VI_ASRL_WIRE_232_DCE = (129)
VI_ASRL_WIRE_232_DTE = (128)
VI_ASRL_WIRE_485_2_AUTO = (3)
VI_ASRL_WIRE_485_2_DTR_CTRL = (2)
VI_ASRL_WIRE_485_2_DTR_ECHO = (1)
VI_ASRL_WIRE_485_4 = (0)
VI_ASSERT_IRQ1 = (1)
VI_ASSERT_IRQ2 = (2)
VI_ASSERT_IRQ3 = (3)
VI_ASSERT_IRQ4 = (4)
VI_ASSERT_IRQ5 = (5)
VI_ASSERT_IRQ6 = (6)
VI_ASSERT_IRQ7 = (7)
VI_ASSERT_SIGNAL = (-1)
VI_ASSERT_USE_ASSIGNED = (0)
VI_ATTR_4882_COMPLIANT = (0x3FFF019F)
VI_ATTR_ASRL_ALLOW_TRANSMIT = (0x3FFF01BE)
VI_ATTR_ASRL_AVAIL_NUM = (0x3FFF00AC)
VI_ATTR_ASRL_BAUD = (0x3FFF0021)
VI_ATTR_ASRL_BREAK_LEN = (0x3FFF01BD)
VI_ATTR_ASRL_BREAK_STATE = (0x3FFF01BC)
VI_ATTR_ASRL_CONNECTED = (0x3FFF01BB)
VI_ATTR_ASRL_CTS_STATE = (0x3FFF00AE)
VI_ATTR_ASRL_DATA_BITS = (0x3FFF0022)
VI_ATTR_ASRL_DCD_STATE = (0x3FFF00AF)
VI_ATTR_ASRL_DISCARD_NULL = (0x3FFF00B0)
VI_ATTR_ASRL_DSR_STATE = (0x3FFF00B1)
VI_ATTR_ASRL_DTR_STATE = (0x3FFF00B2)
VI_ATTR_ASRL_END_IN = (0x3FFF00B3)
VI_ATTR_ASRL_END_OUT = (0x3FFF00B4)
VI_ATTR_ASRL_FLOW_CNTRL = (0x3FFF0025)
VI_ATTR_ASRL_PARITY = (0x3FFF0023)
VI_ATTR_ASRL_REPLACE_CHAR = (0x3FFF00BE)
VI_ATTR_ASRL_RI_STATE = (0x3FFF00BF)
VI_ATTR_ASRL_RTS_STATE = (0x3FFF00C0)
VI_ATTR_ASRL_STOP_BITS = (0x3FFF0024)
VI_ATTR_ASRL_WIRE_MODE = (0x3FFF01BF)
VI_ATTR_ASRL_XOFF_CHAR = (0x3FFF00C2)
VI_ATTR_ASRL_XON_CHAR = (0x3FFF00C1)
VI_ATTR_BUFFER = (0x3FFF4027)
VI_ATTR_CMDR_LA = (0x3FFF006B)
VI_ATTR_DEST_ACCESS_PRIV = (0x3FFF0039)
VI_ATTR_DEST_BYTE_ORDER = (0x3FFF003A)
VI_ATTR_DEST_INCREMENT = (0x3FFF0041)
VI_ATTR_DEV_STATUS_BYTE = (0x3FFF0189)
VI_ATTR_DMA_ALLOW_EN = (0x3FFF001E)
VI_ATTR_EVENT_TYPE = (0x3FFF4010)
VI_ATTR_FDC_CHNL = (0x3FFF000D)
VI_ATTR_FDC_GEN_SIGNAL_EN = (0x3FFF0011)
VI_ATTR_FDC_MODE = (0x3FFF000F)
VI_ATTR_FDC_USE_PAIR = (0x3FFF0013)
VI_ATTR_FILE_APPEND_EN = (0x3FFF0192)
VI_ATTR_FIREWIRE_DEST_UPPER_OFFSET = (0x3FFF01F0)
VI_ATTR_FIREWIRE_LOWER_CHIP_ID = (0x3FFF01F4)
VI_ATTR_FIREWIRE_SRC_UPPER_OFFSET = (0x3FFF01F1)
VI_ATTR_FIREWIRE_UPPER_CHIP_ID = (0x3FFF01F5)
VI_ATTR_FIREWIRE_VENDOR_ID = (0x3FFF01F3)
VI_ATTR_FIREWIRE_WIN_UPPER_OFFSET = (0x3FFF01F2)
VI_ATTR_GPIB_ADDR_STATE = (0x3FFF005C)
VI_ATTR_GPIB_ATN_STATE = (0x3FFF0057)
VI_ATTR_GPIB_CIC_STATE = (0x3FFF005E)
VI_ATTR_GPIB_HS488_CBL_LEN = (0x3FFF0069)
VI_ATTR_GPIB_NDAC_STATE = (0x3FFF0062)
VI_ATTR_GPIB_PRIMARY_ADDR = (0x3FFF0172)
VI_ATTR_GPIB_READDR_EN = (0x3FFF001B)
VI_ATTR_GPIB_RECV_CIC_STATE = (0x3FFF4193)
VI_ATTR_GPIB_REN_STATE = (0x3FFF0181)
VI_ATTR_GPIB_SECONDARY_ADDR = (0x3FFF0173)
VI_ATTR_GPIB_SRQ_STATE = (0x3FFF0067)
VI_ATTR_GPIB_SYS_CNTRL_STATE = (0x3FFF0068)
VI_ATTR_GPIB_UNADDR_EN = (0x3FFF0184)
VI_ATTR_IMMEDIATE_SERV = (0x3FFF0100)
VI_ATTR_INTF_INST_NAME = (0xBFFF00E9)
VI_ATTR_INTF_NUM = (0x3FFF0176)
VI_ATTR_INTF_PARENT_NUM = (0x3FFF0101)
VI_ATTR_INTF_TYPE = (0x3FFF0171)
VI_ATTR_INTR_STATUS_ID = (0x3FFF4023)
VI_ATTR_IO_PROT = (0x3FFF001C)
VI_ATTR_JOB_ID = (0x3FFF4006)
VI_ATTR_MAINFRAME_LA = (0x3FFF0070)
VI_ATTR_MANF_ID = (0x3FFF00D9)
VI_ATTR_MANF_NAME = (0xBFFF0072)
VI_ATTR_MAX_QUEUE_LENGTH = (0x3FFF0005)
VI_ATTR_MEM_BASE_32 = (0x3FFF00AD)
VI_ATTR_MEM_BASE_64 = (0x3FFF00D0)
VI_ATTR_MEM_BASE = (VI_ATTR_MEM_BASE_32)
VI_ATTR_MEM_SIZE_32 = (0x3FFF00DD)
VI_ATTR_MEM_SIZE_64 = (0x3FFF00D1)
VI_ATTR_MEM_SIZE = (VI_ATTR_MEM_SIZE_32)
VI_ATTR_MEM_SPACE = (0x3FFF00DE)
VI_ATTR_MODEL_CODE = (0x3FFF00DF)
VI_ATTR_MODEL_NAME = (0xBFFF0077)
VI_ATTR_OPER_NAME = (0xBFFF4042)
VI_ATTR_PXI_ACTUAL_LWIDTH = (0x3FFF0243)
VI_ATTR_PXI_BUS_NUM = (0x3FFF0205)
VI_ATTR_PXI_CHASSIS = (0x3FFF0206)
VI_ATTR_PXI_DEV_NUM = (0x3FFF0201)
VI_ATTR_PXI_DSTAR_BUS = (0x3FFF0244)
VI_ATTR_PXI_DSTAR_SET = (0x3FFF0245)
VI_ATTR_PXI_FUNC_NUM = (0x3FFF0202)
VI_ATTR_PXI_IS_EXPRESS = (0x3FFF0240)
VI_ATTR_PXI_MAX_LWIDTH = (0x3FFF0242)
VI_ATTR_PXI_MEM_BASE_BAR0 = (0x3FFF0221)
VI_ATTR_PXI_MEM_BASE_BAR1 = (0x3FFF0222)
VI_ATTR_PXI_MEM_BASE_BAR2 = (0x3FFF0223)
VI_ATTR_PXI_MEM_BASE_BAR3 = (0x3FFF0224)
VI_ATTR_PXI_MEM_BASE_BAR4 = (0x3FFF0225)
VI_ATTR_PXI_MEM_BASE_BAR5 = (0x3FFF0226)
VI_ATTR_PXI_MEM_SIZE_BAR0 = (0x3FFF0231)
VI_ATTR_PXI_MEM_SIZE_BAR1 = (0x3FFF0232)
VI_ATTR_PXI_MEM_SIZE_BAR2 = (0x3FFF0233)
VI_ATTR_PXI_MEM_SIZE_BAR3 = (0x3FFF0234)
VI_ATTR_PXI_MEM_SIZE_BAR4 = (0x3FFF0235)
VI_ATTR_PXI_MEM_SIZE_BAR5 = (0x3FFF0236)
VI_ATTR_PXI_MEM_TYPE_BAR0 = (0x3FFF0211)
VI_ATTR_PXI_MEM_TYPE_BAR1 = (0x3FFF0212)
VI_ATTR_PXI_MEM_TYPE_BAR2 = (0x3FFF0213)
VI_ATTR_PXI_MEM_TYPE_BAR3 = (0x3FFF0214)
VI_ATTR_PXI_MEM_TYPE_BAR4 = (0x3FFF0215)
VI_ATTR_PXI_MEM_TYPE_BAR5 = (0x3FFF0216)
VI_ATTR_PXI_SLOT_LBUS_LEFT = (0x3FFF0208)
VI_ATTR_PXI_SLOT_LBUS_RIGHT = (0x3FFF0209)
VI_ATTR_PXI_SLOT_LWIDTH = (0x3FFF0241)
VI_ATTR_PXI_SLOTPATH = (0xBFFF0207)
VI_ATTR_PXI_STAR_TRIG_BUS = (0x3FFF020B)
VI_ATTR_PXI_STAR_TRIG_LINE = (0x3FFF020C)
VI_ATTR_PXI_TRIG_BUS = (0x3FFF020A)
VI_ATTR_RD_BUF_OPER_MODE = (0x3FFF002A)
VI_ATTR_RD_BUF_SIZE = (0x3FFF002B)
VI_ATTR_RECV_INTR_LEVEL = (0x3FFF4041)
VI_ATTR_RECV_TCPIP_ADDR = (0xBFFF4198)
VI_ATTR_RECV_TRIG_ID = (0x3FFF4012)
VI_ATTR_RET_COUNT_32 = (0x3FFF4026)
VI_ATTR_RET_COUNT = (VI_ATTR_RET_COUNT_32)
VI_ATTR_RM_SESSION = (0x3FFF00C4)
VI_ATTR_RSRC_CLASS = (0xBFFF0001)
VI_ATTR_RSRC_IMPL_VERSION = (0x3FFF0003)
VI_ATTR_RSRC_LOCK_STATE = (0x3FFF0004)
VI_ATTR_RSRC_MANF_ID = (0x3FFF0175)
VI_ATTR_RSRC_MANF_NAME = (0xBFFF0174)
VI_ATTR_RSRC_NAME = (0xBFFF0002)
VI_ATTR_RSRC_SPEC_VERSION = (0x3FFF0170)
VI_ATTR_SEND_END_EN = (0x3FFF0016)
VI_ATTR_SIGP_STATUS_ID = (0x3FFF4011)
VI_ATTR_SLOT = (0x3FFF00E8)
VI_ATTR_SRC_ACCESS_PRIV = (0x3FFF003C)
VI_ATTR_SRC_BYTE_ORDER = (0x3FFF003D)
VI_ATTR_SRC_INCREMENT = (0x3FFF0040)
VI_ATTR_STATUS = (0x3FFF4025)
VI_ATTR_SUPPRESS_END_EN = (0x3FFF0036)
VI_ATTR_SYNC_MXI_ALLOW_EN = (0x3FFF0161)
VI_ATTR_TCPIP_ADDR = (0xBFFF0195)
VI_ATTR_TCPIP_DEVICE_NAME = (0xBFFF0199)
VI_ATTR_TCPIP_HOSTNAME = (0xBFFF0196)
VI_ATTR_TCPIP_KEEPALIVE = (0x3FFF019B)
VI_ATTR_TCPIP_NODELAY = (0x3FFF019A)
VI_ATTR_TCPIP_PORT = (0x3FFF0197)
VI_ATTR_TERMCHAR = (0x3FFF0018)
VI_ATTR_TERMCHAR_EN = (0x3FFF0038)
VI_ATTR_TMO_VALUE = (0x3FFF001A)
VI_ATTR_TRIG_ID = (0x3FFF0177)
VI_ATTR_USB_INTFC_NUM = (0x3FFF01A1)
VI_ATTR_USB_MAX_INTR_SIZE = (0x3FFF01AF)
VI_ATTR_USB_PROTOCOL = (0x3FFF01A7)
VI_ATTR_USB_RECV_INTR_DATA = (0xBFFF41B1)
VI_ATTR_USB_RECV_INTR_SIZE = (0x3FFF41B0)
VI_ATTR_USB_SERIAL_NUM = (0xBFFF01A0)
VI_ATTR_USER_DATA_32 = (0x3FFF0007)
VI_ATTR_USER_DATA = (VI_ATTR_USER_DATA_32)
VI_ATTR_VXI_DEV_CLASS = (0x3FFF006C)
VI_ATTR_VXI_DEV_CMD_TYPE = (0x3FFF4037)
VI_ATTR_VXI_DEV_CMD_VALUE = (0x3FFF4038)
VI_ATTR_VXI_LA = (0x3FFF00D5)
VI_ATTR_VXI_TRIG_STATUS = (0x3FFF008D)
VI_ATTR_VXI_TRIG_SUPPORT = (0x3FFF0194)
VI_ATTR_VXI_VME_INTR_STATUS = (0x3FFF008B)
VI_ATTR_VXI_VME_SYSFAIL_STATE = (0x3FFF0094)
VI_ATTR_WIN_ACCESS = (0x3FFF00C3)
VI_ATTR_WIN_ACCESS_PRIV = (0x3FFF0045)
VI_ATTR_WIN_BASE_ADDR_32 = (0x3FFF0098)
VI_ATTR_WIN_BASE_ADDR_64 = (0x3FFF009B)
VI_ATTR_WIN_BASE_ADDR = (VI_ATTR_WIN_BASE_ADDR_32)
VI_ATTR_WIN_BYTE_ORDER = (0x3FFF0047)
VI_ATTR_WIN_SIZE_32 = (0x3FFF009A)
VI_ATTR_WIN_SIZE_64 = (0x3FFF009C)
VI_ATTR_WIN_SIZE = (VI_ATTR_WIN_SIZE_32)
VI_ATTR_WR_BUF_OPER_MODE = (0x3FFF002D)
VI_ATTR_WR_BUF_SIZE = (0x3FFF002E)
VI_BIG_ENDIAN = (0)
VI_BLCK_NPRIV = (5)
VI_BLCK_PRIV = (4)
VI_D64_NPRIV = (7)
VI_D64_PRIV = (6)
VI_DATA_NPRIV = (1)
VI_DATA_PRIV = (0)
VI_DEREF_ADDR = (3)
VI_DEREF_ADDR_BYTE_SWAP = (4)
VI_ERROR_ABORT = (_VI_ERROR + 0x3FFF0030)
VI_ERROR_ALLOC = (_VI_ERROR + 0x3FFF003C)
VI_ERROR_ASRL_FRAMING = (_VI_ERROR + 0x3FFF006B)
VI_ERROR_ASRL_OVERRUN = (_VI_ERROR + 0x3FFF006C)
VI_ERROR_ASRL_PARITY = (_VI_ERROR + 0x3FFF006A)
VI_ERROR_ATTR_READONLY = (_VI_ERROR + 0x3FFF001F)
VI_ERROR_BERR = (_VI_ERROR + 0x3FFF0038)
VI_ERROR_CLOSING_FAILED = (_VI_ERROR + 0x3FFF0016)
VI_ERROR_CONN_LOST = (_VI_ERROR + 0x3FFF00A6)
VI_ERROR_FAIL_ID_QUERY = (_VI_ERROR + 0x3FFC0011)
VI_ERROR_FILE_ACCESS = (_VI_ERROR + 0x3FFF00A1)
VI_ERROR_FILE_IO = (_VI_ERROR + 0x3FFF00A2)
VI_ERROR_HNDLR_NINSTALLED = (_VI_ERROR + 0x3FFF0028)
VI_ERROR_INP_PROT_VIOL = (_VI_ERROR + 0x3FFF0037)
VI_ERROR_IN_PROGRESS = (_VI_ERROR + 0x3FFF0039)
VI_ERROR_INTF_NUM_NCONFIG = (_VI_ERROR + 0x3FFF00A5)
VI_ERROR_INTR_PENDING = (_VI_ERROR + 0x3FFF0068)
VI_ERROR_INV_ACCESS_KEY = (_VI_ERROR + 0x3FFF0021)
VI_ERROR_INV_ACC_MODE = (_VI_ERROR + 0x3FFF0013)
VI_ERROR_INV_CONTEXT = (_VI_ERROR + 0x3FFF002A)
VI_ERROR_INV_DEGREE = (_VI_ERROR + 0x3FFF001B)
VI_ERROR_INV_EVENT = (_VI_ERROR + 0x3FFF0026)
VI_ERROR_INV_EXPR = (_VI_ERROR + 0x3FFF0010)
VI_ERROR_INV_FMT = (_VI_ERROR + 0x3FFF003F)
VI_ERROR_INV_HNDLR_REF = (_VI_ERROR + 0x3FFF0029)
VI_ERROR_INV_JOB_ID = (_VI_ERROR + 0x3FFF001C)
VI_ERROR_INV_LENGTH = (_VI_ERROR + 0x3FFF0083)
VI_ERROR_INV_LINE = (_VI_ERROR + 0x3FFF00A0)
VI_ERROR_INV_LOCK_TYPE = (_VI_ERROR + 0x3FFF0020)
VI_ERROR_INV_MASK = (_VI_ERROR + 0x3FFF003D)
VI_ERROR_INV_MECH = (_VI_ERROR + 0x3FFF0027)
VI_ERROR_INV_MODE = (_VI_ERROR + 0x3FFF0091)
VI_ERROR_INV_OBJECT = (_VI_ERROR + 0x3FFF000E)
VI_ERROR_INV_OFFSET = (_VI_ERROR + 0x3FFF0051)
VI_ERROR_INV_PARAMETER = (_VI_ERROR + 0x3FFF0078)
VI_ERROR_INV_PROT = (_VI_ERROR + 0x3FFF0079)
VI_ERROR_INV_RESPONSE = (_VI_ERROR + 0x3FFC0012)
VI_ERROR_INV_RSRC_NAME = (_VI_ERROR + 0x3FFF0012)
VI_ERROR_INV_SESSION = (VI_ERROR_INV_OBJECT)
VI_ERROR_INV_SETUP = (_VI_ERROR + 0x3FFF003A)
VI_ERROR_INV_SIZE = (_VI_ERROR + 0x3FFF007B)
VI_ERROR_INV_SPACE = (_VI_ERROR + 0x3FFF004E)
VI_ERROR_INV_WIDTH = (_VI_ERROR + 0x3FFF0052)
VI_ERROR_IO = (_VI_ERROR + 0x3FFF003E)
VI_ERROR_LIBRARY_NFOUND = (_VI_ERROR + 0x3FFF009E)
VI_ERROR_LINE_IN_USE = (_VI_ERROR + 0x3FFF0042)
VI_ERROR_MACHINE_NAVAIL = (_VI_ERROR + 0x3FFF00A7)
VI_ERROR_MEM_NSHARED = (_VI_ERROR + 0x3FFF009D)
VI_ERROR_NCIC = (_VI_ERROR + 0x3FFF0060)
VI_ERROR_NENABLED = (_VI_ERROR + 0x3FFF002F)
VI_ERROR_NIMPL_OPER = (_VI_ERROR + 0x3FFF0081)
VI_ERROR_NLISTENERS = (_VI_ERROR + 0x3FFF005F)
VI_ERROR_NPERMISSION = (_VI_ERROR + 0x3FFF00A8)
VI_ERROR_NSUP_ALIGN_OFFSET = (_VI_ERROR + 0x3FFF0070)
VI_ERROR_NSUP_ATTR_STATE = (_VI_ERROR + 0x3FFF001E)
VI_ERROR_NSUP_ATTR = (_VI_ERROR + 0x3FFF001D)
VI_ERROR_NSUP_FMT = (_VI_ERROR + 0x3FFF0041)
VI_ERROR_NSUP_INTR = (_VI_ERROR + 0x3FFF009F)
VI_ERROR_NSUP_LINE = (_VI_ERROR + 0x3FFF00A3)
VI_ERROR_NSUP_MECH = (_VI_ERROR + 0x3FFF00A4)
VI_ERROR_NSUP_MODE = (_VI_ERROR + 0x3FFF0046)
VI_ERROR_NSUP_OFFSET = (_VI_ERROR + 0x3FFF0054)
VI_ERROR_NSUP_OPER = (_VI_ERROR + 0x3FFF0067)
VI_ERROR_NSUP_VAR_WIDTH = (_VI_ERROR + 0x3FFF0055)
VI_ERROR_NSUP_WIDTH = (_VI_ERROR + 0x3FFF0076)
VI_ERROR_NSYS_CNTLR = (_VI_ERROR + 0x3FFF0061)
VI_ERROR_OUTP_PROT_VIOL = (_VI_ERROR + 0x3FFF0036)
VI_ERROR_PARAMETER1 = (_VI_ERROR + 0x3FFC0001)
VI_ERROR_PARAMETER2 = (_VI_ERROR + 0x3FFC0002)
VI_ERROR_PARAMETER3 = (_VI_ERROR + 0x3FFC0003)
VI_ERROR_PARAMETER4 = (_VI_ERROR + 0x3FFC0004)
VI_ERROR_PARAMETER5 = (_VI_ERROR + 0x3FFC0005)
VI_ERROR_PARAMETER6 = (_VI_ERROR + 0x3FFC0006)
VI_ERROR_PARAMETER7 = (_VI_ERROR + 0x3FFC0007)
VI_ERROR_PARAMETER8 = (_VI_ERROR + 0x3FFC0008)
VI_ERROR_QUEUE_ERROR = (_VI_ERROR + 0x3FFF003B)
VI_ERROR_QUEUE_OVERFLOW = (_VI_ERROR + 0x3FFF002D)
VI_ERROR_RAW_RD_PROT_VIOL = (_VI_ERROR + 0x3FFF0035)
VI_ERROR_RAW_WR_PROT_VIOL = (_VI_ERROR + 0x3FFF0034)
VI_ERROR_RESP_PENDING = (_VI_ERROR + 0x3FFF0059)
VI_ERROR_RSRC_BUSY = (_VI_ERROR + 0x3FFF0072)
VI_ERROR_RSRC_LOCKED = (_VI_ERROR + 0x3FFF000F)
VI_ERROR_RSRC_NFOUND = (_VI_ERROR + 0x3FFF0011)
VI_ERROR_SESN_NLOCKED = (_VI_ERROR + 0x3FFF009C)
VI_ERROR_SRQ_NOCCURRED = (_VI_ERROR + 0x3FFF004A)
VI_ERROR_SYSTEM_ERROR = (_VI_ERROR + 0x3FFF0000)
VI_ERROR_TMO = (_VI_ERROR + 0x3FFF0015)
VI_ERROR_TRIG_NMAPPED = (_VI_ERROR + 0x3FFF006E)
VI_ERROR_USER_BUF = (_VI_ERROR + 0x3FFF0071)
VI_ERROR_WINDOW_MAPPED = (_VI_ERROR + 0x3FFF0080)
VI_ERROR_WINDOW_NMAPPED = (_VI_ERROR + 0x3FFF0057)
VI_EVENT_ASRL_BREAK = (0x3FFF2023)
VI_EVENT_ASRL_CHAR = (0x3FFF2035)
VI_EVENT_ASRL_CTS = (0x3FFF2029)
VI_EVENT_ASRL_DCD = (0x3FFF202C)
VI_EVENT_ASRL_DSR = (0x3FFF202A)
VI_EVENT_ASRL_RI = (0x3FFF202E)
VI_EVENT_ASRL_TERMCHAR = (0x3FFF2024)
VI_EVENT_CLEAR = (0x3FFF200D)
VI_EVENT_EXCEPTION = (0xBFFF200E)
VI_EVENT_GPIB_CIC = (0x3FFF2012)
VI_EVENT_GPIB_LISTEN = (0x3FFF2014)
VI_EVENT_GPIB_TALK = (0x3FFF2013)
VI_EVENT_IO_COMPLETION = (0x3FFF2009)
VI_EVENT_PXI_INTR = (0x3FFF2022)
VI_EVENT_SERVICE_REQ = (0x3FFF200B)
VI_EVENT_TCPIP_CONNECT = (0x3FFF2036)
VI_EVENT_TRIG = (0xBFFF200A)
VI_EVENT_USB_INTR = (0x3FFF2037)
VI_EVENT_VXI_DEV_CMD = (0xBFFF200F)
VI_EVENT_VXI_SIGP = (0x3FFF2020)
VI_EVENT_VXI_VME_INTR = (0xBFFF2021)
VI_EVENT_VXI_VME_SYSFAIL = (0x3FFF201D)
VI_EVENT_VXI_VME_SYSRESET = (0x3FFF201E)
VI_EXCLUSIVE_LOCK = (1)
VI_FDC_NORMAL = (1)
VI_FDC_STREAM = (2)
VI_FDC = (VI_PROT_FDC)
VI_FIND_BUFLEN = (256)
VI_FIREWIRE_DFLT_SPACE = (5)
VI_FLUSH_DISABLE = (3)
VI_FLUSH_ON_ACCESS = (1)
VI_FLUSH_WHEN_FULL = (2)
VI_GPIB_ATN_ASSERT = (1)
VI_GPIB_ATN_ASSERT_IMMEDIATE = (3)
VI_GPIB_ATN_DEASSERT = (0)
VI_GPIB_ATN_DEASSERT_HANDSHAKE = (2)
VI_GPIB_HS488_DISABLED = (0)
VI_GPIB_HS488_NIMPL = (-1)
VI_GPIB_LISTENER = (2)
VI_GPIB_REN_ADDRESS_GTL = (6)
VI_GPIB_REN_ASSERT = (1)
VI_GPIB_REN_ASSERT_ADDRESS = (3)
VI_GPIB_REN_ASSERT_ADDRESS_LLO = (5)
VI_GPIB_REN_ASSERT_LLO = (4)
VI_GPIB_REN_DEASSERT = (0)
VI_GPIB_REN_DEASSERT_GTL = (2)
VI_GPIB_TALKER = (1)
VI_GPIB_UNADDRESSED = (0)
VI_HNDLR = (2)
VI_HS488 = (VI_PROT_HS488)
VI_INFINITE = (VI_TMO_INFINITE)
VI_INTF_ASRL = (4)
VI_INTF_FIREWIRE = (9)
VI_INTF_GPIB = (1)
VI_INTF_GPIB_VXI = (3)
VI_INTF_PXI = (5)
VI_INTF_RIO = (8)
VI_INTF_TCPIP = (6)
VI_INTF_USB = (7)
VI_INTF_VXI = (2)
VI_LITTLE_ENDIAN = (1)
VI_LOAD_CONFIG = (4)
VI_LOCAL_SPACE = (0)
VI_NMAPPED = (1)
VI_NO_LOCK = (0)
VI_NORMAL = (VI_PROT_NORMAL)
VI_NO_SEC_ADDR = (0xFFFF)
VI_OFF = (0)
VI_ON = (1)
VI_OPAQUE_SPACE = (0xFFFF)
VI_PROG_NPRIV = (3)
VI_PROG_PRIV = (2)
VI_PROT_USBTMC_VENDOR = (5)
VI_PXI_ADDR_CFG = (3)
VI_PXI_ADDR_IO = (2)
VI_PXI_ADDR_MEM = (1)
VI_PXI_ADDR_NONE = (0)
VI_PXI_ALLOC_SPACE = (9)
VI_PXI_BAR0_SPACE = (11)
VI_PXI_BAR1_SPACE = (12)
VI_PXI_BAR2_SPACE = (13)
VI_PXI_BAR3_SPACE = (14)
VI_PXI_BAR4_SPACE = (15)
VI_PXI_BAR5_SPACE = (16)
VI_PXI_CFG_SPACE = (10)
VI_PXI_LBUS_NONE = (0)
VI_PXI_LBUS_STAR_TRIG_BUS_0 = (1000)
VI_PXI_LBUS_STAR_TRIG_BUS_1 = (1001)
VI_PXI_LBUS_STAR_TRIG_BUS_2 = (1002)
VI_PXI_LBUS_STAR_TRIG_BUS_3 = (1003)
VI_PXI_LBUS_STAR_TRIG_BUS_4 = (1004)
VI_PXI_LBUS_STAR_TRIG_BUS_5 = (1005)
VI_PXI_LBUS_STAR_TRIG_BUS_6 = (1006)
VI_PXI_LBUS_STAR_TRIG_BUS_7 = (1007)
VI_PXI_LBUS_STAR_TRIG_BUS_8 = (1008)
VI_PXI_LBUS_STAR_TRIG_BUS_9 = (1009)
VI_PXI_LBUS_UNKNOWN = (-1)
VI_PXI_STAR_TRIG_CONTROLLER = (1413)
VI_QUEUE = (1)
VI_READ_BUF = (1)
VI_READ_BUF_DISCARD = (4)
VI_SHARED_LOCK = (2)
VI_SPEC_VERSION = (0x00400000)
VI_STATE_ASSERTED = (1)
VI_STATE_UNASSERTED = (0)
VI_STATE_UNKNOWN = (-1)
VI_SUCCESS = (0)
VI_SUCCESS_DEV_NPRESENT = (0x3FFF007D)
VI_SUCCESS_EVENT_DIS = (0x3FFF0003)
VI_SUCCESS_EVENT_EN = (0x3FFF0002)
VI_SUCCESS_MAX_CNT = (0x3FFF0006)
VI_SUCCESS_NCHAIN = (0x3FFF0098)
VI_SUCCESS_NESTED_EXCLUSIVE = (0x3FFF009A)
VI_SUCCESS_NESTED_SHARED = (0x3FFF0099)
VI_SUCCESS_QUEUE_EMPTY = (0x3FFF0004)
VI_SUCCESS_QUEUE_NEMPTY = (0x3FFF0080)
VI_SUCCESS_SYNC = (0x3FFF009B)
VI_SUCCESS_TERM_CHAR = (0x3FFF0005)
VI_SUCCESS_TRIG_MAPPED = (0x3FFF007E)
VI_SUSPEND_HNDLR = (4)
VI_TRIG_ALL = (-2)
VI_TRIG_ECL0 = (8)
VI_TRIG_ECL1 = (9)
VI_TRIG_PANEL_IN = (27)
VI_TRIG_PANEL_OUT = (28)
VI_TRIG_PROT_DEFAULT = (0)
VI_TRIG_PROT_OFF = (2)
VI_TRIG_PROT_ON = (1)
VI_TRIG_PROT_RESERVE = (6)
VI_TRIG_PROT_SYNC = (5)
VI_TRIG_PROT_UNRESERVE = (7)
VI_TRIG_SW = (-1)
VI_TRIG_TTL0 = (0)
VI_TRIG_TTL1 = (1)
VI_TRIG_TTL2 = (2)
VI_TRIG_TTL3 = (3)
VI_TRIG_TTL4 = (4)
VI_TRIG_TTL5 = (5)
VI_TRIG_TTL6 = (6)
VI_TRIG_TTL7 = (7)
VI_TRIG_UNKNOWN = (-1)
VI_UNKNOWN_CHASSIS = (-1)
VI_UNKNOWN_LA = (-1)
VI_UNKNOWN_LEVEL = (-1)
VI_UNKNOWN_SLOT = (-1)
VI_USE_OPERS = (2)
VI_UTIL_ASSERT_SYSFAIL = (2)
VI_UTIL_ASSERT_SYSRESET = (1)
VI_UTIL_DEASSERT_SYSFAIL = (3)
VI_VXI_CLASS_EXTENDED = (1)
VI_VXI_CLASS_MEMORY = (0)
VI_VXI_CLASS_MESSAGE = (2)
VI_VXI_CLASS_OTHER = (4)
VI_VXI_CLASS_REGISTER = (3)
VI_VXI_CMD16 = (0x0200)
VI_VXI_CMD16_RESP16 = (0x0202)
VI_VXI_CMD32 = (0x0400)
VI_VXI_CMD32_RESP16 = (0x0402)
VI_VXI_CMD32_RESP32 = (0x0404)
VI_VXI_DEV_CMD_TYPE_16 = (16)
VI_VXI_DEV_CMD_TYPE_32 = (32)
VI_VXI_RESP16 = (0x0002)
VI_VXI_RESP32 = (0x0004)
VI_VXI_RESP_NONE = (0)
VI_VXI_RESP_PROT_ERROR = (-1)
VI_WARN_CONFIG_NLOADED = (0x3FFF0077)
VI_WARN_EXT_FUNC_NIMPL = (0x3FFF00A9)
VI_WARN_NSUP_ATTR_STATE = (0x3FFF0084)
VI_WARN_NSUP_BUF = (0x3FFF0088)
VI_WARN_NSUP_ERROR_QUERY = (0x3FFC0104)
VI_WARN_NSUP_ID_QUERY = (0x3FFC0101)
VI_WARN_NSUP_RESET = (0x3FFC0102)
VI_WARN_NSUP_REV_QUERY = (0x3FFC0105)
VI_WARN_NSUP_SELF_TEST = (0x3FFC0103)
VI_WARN_NULL_OBJECT = (0x3FFF0082)
VI_WARN_QUEUE_OVERFLOW = (0x3FFF000C)
VI_WARN_UNKNOWN_STATUS = (0x3FFF0085)
VI_WIDTH_16 = (2)
VI_WIDTH_32 = (4)
VI_WIDTH_64 = (8)
VI_WIDTH_8 = (1)
VI_WRITE_BUF = (2)
VI_WRITE_BUF_DISCARD = (8)
